#include "Sequencer.h"

uint8_t ReadFlash(uint8_t* pos)
{
	return pgm_read_byte(pos);
}

void seq_update(void)
{
	uint8_t data;
	if(Seq.state & (1<<SEQ_STATE_EN))
	{
		if(--Seq.tempocounter == 0)
		{
			Seq.tempocounter = Seq.tempo;		

			Oscillator* oscs = synth.oscillators;
			uint8_t* file = Seq.file;
			ReadFunc read = Seq.read;
			uint8_t counter = CHANNELS;
			uint8_t active = 0;			//Diese Variable prft ob alle Oscs beendet sind
			do
			{
				if(oscs->state < OSC_STATE_END)
				{
					active = 1;
					uint16_t duration = oscs->seq_data;
					if(--duration == 0)
					{
next_instruction:		//Nchsten Befehl laden
						data = read(file++);
						if((data & 0x80) == 0)							//Note On
						{
							synth_set_note(oscs, data);
							duration = read(file) | read(file+1) << 8;
							file += 2;
						}
						else
						{
							switch(data)
							{
								case SI_END:
									oscs->state = OSC_STATE_END;
									break;
								case SI_DELAY:
									oscs->state = OSC_STATE_DELAY;
									duration = read(file) | read(file+1) << 8;
									file += 2;
									break;
								case SI_SOUND:;
									synth_set_sound(oscs, read(file++));
									goto next_instruction;
									break;
								case SI_VOLUME:
									oscs->temp = read(file++);
									goto next_instruction;
							}
						}
					}
					oscs->seq_data = duration;
				}
				oscs++;
			}
			while(--counter);
			Seq.file = file;
			if(!active)
				seq_stop();
		}
	}
}

int8_t seq_load(ReadFunc read, uint8_t* data)
{
	uint8_t channels = read(data++);
	if(channels > CHANNELS)
		return -1;		//Zu wenige Kanle
	Seq.tempo = read(data++);
	Seq.tempocounter = 1;
	Seq.file = data;
	Seq.read = read;
	synth_reset_oscs(channels);
	return 0;
}


#define OS_PERCUSSION 35

const uint8_t percussion[]	PROGMEM = {
//				Sound,				Note,	Volume-Multiplikator
PERCUSSION_START + OS_BASSDRUM, 	6,		5,		//35 Bass Drum 2
PERCUSSION_START + OS_BASSDRUM, 	6,		5,		//36 Bass Drum 1
255,								255,	1,		//37 Side Stick
PERCUSSION_START + OS_SNARE, 		18,		3,		//38 Snare Drum 1
255, 								255,	1,		//39 Hand Clap
PERCUSSION_START + OS_SNARE, 		18,		3,		//40 Snare Drum 2
255, 								255,	1,		//41 Low Tom 2
PERCUSSION_START + OS_HIHAT, 		42,		1,		//42 Closed Hi-hat
255, 								255,	1,		//43 Low Tom 1
PERCUSSION_START + OS_HIHAT, 		42,		1,		//44 Pedal Hi-hat
255, 								255,	1,		//45 Mid Tom 2
PERCUSSION_START + OS_HIHAT, 		42,		1,		//46 Open Hi-hat
255, 								255,	1,		//47 Mid Tom 1
255, 								255,	1,		//48 High Tom 2
255, 								255,	1,		//49 Crash Cymbal 1
255, 								255,	1,		//50 High Tom 1
255, 								255,	1,		//51 Ride Cymbal 1
255, 								255,	1,		//52 Chinese Cymbal
255, 								255,	1,		//53 Ride Bell
255, 								255,	1,		//54 Tambourine
255, 								255,	1,		//55 Splash Cymbal
255, 								255,	1,		//56 Cowbell
255, 								255,	1,		//57 Crash Cymbal 2
255, 								255,	1,		//58 Vibra Slap
255, 								255,	1,		//59 Ride Cymbal 2
255, 								255,	1,		//60 High Bongo
255, 								255,	1,		//61 Low Bongo
255, 								255,	1,		//62 Mute High Conga
255, 								255,	1,		//63 Open High Conga
255, 								255,	1,		//64 Low Conga
255, 								255,	1,		//65 High Timbale
255, 								255,	1,		//66 Low Timbale
255, 								255,	1,		//67 High Agogo
255, 								255,	1,		//68 Low Agogo
255, 								255,	1,		//69 Cabasa
255, 								255,	1,		//70 Maracas
255, 								255,	1,		//71 Short Whistle
255, 								255,	1,		//72 Long Whistle
255, 								255,	1,		//73 Short Guiro
255, 								255,	1,		//74 Long Guiro
255, 								255,	1,		//75 Claves
255, 								255,	1,		//76 High Wood Block
255, 								255,	1,		//77 Low Wood Block
255, 								255,	1,		//78 Mute Cuica
255, 								255,	1,		//79 Open Cuica
255, 								255,	1,		//80 Mute Triangle
255, 								255,	1		//81 Open Triangle
};

void synth_set_note(Oscillator* osc, uint8_t note)
{
	osc->volume = osc->temp;
	if(osc->sound >= PERCUSSION_START)
	{
		note -= OS_PERCUSSION;
		if(note < 47)
		{
			note *= 3;
			uint8_t* ptr = (uint8_t*)&(percussion[note]); 
			uint8_t sound = pgm_read_byte(ptr++);
			if(sound == 255)
			{
				osc->state = OSC_STATE_DELAY;
				return;
			}
			osc->sound = sound;
			note = pgm_read_byte(ptr++);
			osc->volume = osc->temp * pgm_read_byte(ptr);
		}
	}		
	osc->sound &= 254;
	uint8_t* ptr = (((uint8_t*)&SoundInfo)+osc->sound * SoundInfoLen/2);
	uint8_t div = pgm_read_byte(ptr++);
	uint8_t div2 = pgm_read_byte(ptr++);
	uint8_t vel = pgm_read_byte(ptr++);//Hier attack_velocity
	if(vel)
	{
		osc->state = OSC_STATE_ATTACK;
		osc->release = 0;
	}
	else
	{
		vel = pgm_read_byte(ptr);
		osc->state = OSC_STATE_NOTE_ON;
		osc->release = 255;
	}	
	osc->release_vel = vel;
	uint16_t temp = pgm_read_word((uint8_t*)(&Tones+note));
	osc->freq = (temp + div/2) / div;
	osc->sustain_freq = (temp + div2/2) / div2;
	osc->freqcounter = 0;
}

const uint8_t sound_t[128] PROGMEM = {
//Piano:
2,//1 Acoustic Grand Piano
2,//2 Bright Acoustic Piano
2,//3 Electric Grand Piano
2,//4 Honky-tonk Piano
2,//5 Electric Piano 1
2,//6 Electric Piano 2
2,//7 Harpsichord
2,//8 Clavi
//Chromatic Percussion:
0,//9 Celesta
0,//10 Glockenspiel
0,//11 Music Box
0,//12 Vibraphone
0,//13 Marimba
0,//14 Xylophone
0,//15 Tubular Bells
0,//16 Dulcimer
//Organ:
6,//17 Organ
6,//18 Percussive Organ
6,//19 Rock Organ
6,//20 Church Organ
6,//21 Reed Organ
6,//22 Accordion
6,//23 Harmonica
6,//24 Tango Accordion
//Guitar:
0,//25 Acoustic Guitar (nylon)
0,//26 Acoustic Guitar (steel)
0,//27 Electric Guitar (jazz)
0,//28 Electric Guitar (clean)
0,//29 Electric Guitar (muted)
0,//30 Overdriven Guitar
0,//31 Distortion Guitar
0,//32 Guitar harmonics
//Bass:
4,//33 Acoustic Bass
4,//34 Electric Bass (finger)
4,//35 Electric Bass (pick)
4,//36 Fretless Bass
4,//37 Slap Bass 1
4,//38 Slap Bass 2
4,//39 Synth Bass 1
4,//40 Synth Bass 2
//Strings:
8,//41 Violin
8,//42 Viola
8,//43 Cello
8,//44 Contrabass
8,//45 Tremolo Strings
8,//46 Pizzicato Strings
8,//47 Orchestral Harp
8,//48 Timpani
//Ensemble:
8,//49 String Ensemble 1
8,//50 String Ensemble 2
4,//51 Synth Strings 1
4,//52 Synth Strings 2
8,//53 Voice Aahs
8,//54 Voice Oohs
1,//55 Synth Voice
8,//56 Orchestra Hit
//Brass:
10,//57 Trumpet
10,//58 Trombone
10,//59 Tuba
10,//60 Muted Trumpet
8,//61 French horn
8,//62 Brass Section
4,//63 Synth Brass 1
4,//64 Synth Brass 2
//Reed:
10,//65 Soprano Sax
10,//66 Alto Sax
10,//67 Tenor Sax
10,//68 Baritone Sax
4,//69 Oboe
8,//70 English Horn
10,//71 Bassoon
4,//72 Clarinet
//Pipe:
0,//73 Piccolo
0,//74 Flute
0,//75 Recorder
0,//76 Pan Flute
0,//77 Blown Bottle
0,//78 Shakuhachi
0,//79 Whistle
0,//80 Ocarina
//Synth Lead:
4,//81 Lead 1 (square)
4,//82 Lead 2 (sawtooth)
4,//83 Lead 3 (calliope)
4,//84 Lead 4 (chiff)
4,//85 Lead 5 (charang)
4,//86 Lead 6 (voice)
4,//87 Lead 7 (fifths)
4,//88 Lead 8 (bass + lead)
//Synth Pad:
4,//89 Pad 1 (new age)
4,//90 Pad 2 (warm)
4,//91 Pad 3 (polysynth)
1,//92 Pad 4 (choir)
4,//93 Pad 5 (bowed)
4,//94 Pad 6 (metallic)
0,//95 Pad 7 (halo)
0,//96 Pad 8 (sweep)
//Synth Effects:
4,//97 FX 1 (rain)
4,//98 FX 2 (soundtrack)
0,//99 FX 3 (crystal)
0,//100 FX 4 (atmosphere)
0,//101 FX 5 (brightness)
0,//102 FX 6 (goblins)
0,//103 FX 7 (echoes)
0,//104 FX 8 (sci-fi)
//Ethnic:
4,//105 Sitar
2,//106 Banjo
4,//107 Shamisen
4,//108 Koto
4,//109 Kalimba
4,//110 Bagpipe
0,//111 Fiddle
4,//112 Shanai
//Percussive:
4,//113 Tinkle Bell
4,//114 Agogo Bells
4,//115 Steel Drums
4,//116 Woodblock
4,//117 Taiko Drum
4,//118 Melodic Tom
4,//119 Synth Drum
4,//120 Reverse Cymbal
//Sound effects:
4,//121 Guitar Fret Noise
4,//122 Breath Noise
4,//123 Seashore
4,//124 Bird Tweet
4,//125 Telephone Ring
4,//126 Helicopter
4,//127 Applause
4};//128 Gunshot

void synth_set_sound(Oscillator* osc, uint8_t sound)
{
	osc->sound = sound >= 128 ? 255 : pgm_read_byte(&(sound_t[sound]));
}
