/* 
 * Synthesizer Konfiguration
 */

/*
 * Hardware
 */

#ifndef F_CPU
#define F_CPU 16000000
#warning "F_CPU wird auf 16Mhz gesetzt."
#endif

#if defined(__AVR_ATmega48__)		\
 || defined(__AVR_ATmega88__)		\
 || defined(__AVR_ATmega168__)		\
 || defined(__AVR_ATmega328__)		\
 || defined(__AVR_ATmega328P__)
	#define PWM_DDR DDRB
	#define PWM_PIN 1
	//#define PWM_DDR DDRB
	//#define PWM_PIN 2
#elif defined(__AVR_ATmega164__)	\
 || defined(__AVR_ATmega324__)		\
 || defined(__AVR_ATmega644__)		\
 || defined(__AVR_ATmega1284__)
	#define PWM_DDR DDRD
	#define PWM_PIN 5
	//#define PWM_DDR DDRD
	//#define PWM_PIN 4
#else
	#define PWM_DDR __DDR__
	#define PWM_PIN __X__
	
#if PWM_DDR == __DDR__
	#error "Hardwaredaten manuell eintragen!"
#endif
#endif


/*
 * Timer
 */

#define TIMER1				//Timer auswhlen
#define PWMA				//PWM-Channel auswhlen (A/B)
#define PWM_REG OCR1A		//PWM-Register
#define PWM_REGL OCR1AL		//PWM-Low-Register
#define PWM_REGH OCR1AH		//PWM-High-Register

//Hier den Code fr die (De-)Aktivierung des ausgewhlten Timers eintragen
#define START_SYNTH() TIMSK1 |= (1<<OCIE1A)
#define STOP_SYNTH() TIMSK1 &= ~(1<<OCIE1A)


/*
 * Synth
 */

#define SAMPLE_FREQ		44100				//Samplefrequenz in Hz
#define CHANNELS		37					//Maximal mgliche Kanle. Je mehr, desto mehr Leistung wird bentigt
#define BUF_LEN 		128					//Funktioniert zurzeit nur mit 128


/*
 * Sonstiges
 */

//Hier knnen 3 C-Funktionen angegeben werden, die im 1kHz-Takt aufgerufen werden
#define MSEC_CFUNC1		seq_update
//#define MSEC_CFUNC2
//#define MSEC_CFUNC3


 /* 
  * Debug
  */

//#define DEBUG_PWM






/************************************************************************
 *								DO NOT CHANGE							*
 ************************************************************************/

#define PERCUSSION_START	12
#define NR_SAMPLE_START		14			//Samples (=Sounds), die nicht wiederholend sind

#define OS_BASSDRUM	0
#define OS_SNARE	2
#define OS_HIHAT	4


#define MS_COMP			(((SAMPLE_FREQ + 500) / 1000 - 1) * 2) // *2, da YL in Timerinterrupt immer um 2 erhht wird

#define RELEASE_PRESCALER 16

#define REFRESH_RATE		(BUF_LEN / 2)

#if defined(TIMER0) || defined(TIMER2)
	#define TIMER_SIZE 8
#elif defined(TIMER1) || defined(TIMER3)
	#define TIMER_SIZE 16
#else 
	#error "Definierter Timer existiert nicht!"
#endif



#if BUF_LEN > 128
	#error "BUF_LEN ist grer als 128 Byte!"
#endif

#define TOP_V ((F_CPU+SAMPLE_FREQ/2) / SAMPLE_FREQ)

#if TOP_V >= (1<<TIMER_SIZE)
	#error "F_CPU zu hoch fuer gewhlten Timer!"
#endif

#if TOP_V < 64
	#error "Minimum ist 6bit PWM!"
#elif TOP_V < 128
	#define PWM_SIZE 6
	#ifdef DEBUG_PWM
		#warning "6bit PWM"
	#endif
#elif TOP_V < 256
	#define PWM_SIZE 7
	#ifdef DEBUG_PWM
		#warning "7bit PWM"
	#endif
#elif TOP_V < 512
	#define PWM_SIZE 8
	#ifdef DEBUG_PWM
		#warning "8bit PWM"
	#endif
#elif TOP_V < 1024
	#define PWM_SIZE 9
	#ifdef DEBUG_PWM
		#warning "9bit PWM"
	#endif
#elif TOP_V < 2048
	#define PWM_SIZE 10
	#ifdef DEBUG_PWM
		#warning "10bit PWM"
	#endif
#elif TOP_V < 4096
	#define PWM_SIZE 11
	#ifdef DEBUG_PWM
		#warning "11bit PWM"
	#endif
#elif TOP_V < 8192
	#define PWM_SIZE 12
	#ifdef DEBUG_PWM
		#warning "12bit PWM"
	#endif
#else
	#error "PWM-Mode nicht definiert!"
#endif
