#include "Synthesizer.h"

void synth_init(void)
{
	synth.read = synth.write = synth.buffer;
	synth.comp = synth.ms_comp = (uint8_t)(uint16_t)synth.buffer;
	synth.release_counter = RELEASE_PRESCALER;
	
	uint8_t i = BUF_LEN;
	uint16_t* ptr = synth.buffer;
	do
	{
		*ptr++ = 0x8000;
	}
	while(--i);
	i = CHANNELS;
	
	Oscillator* ptr2 = synth.oscillators;
	do
	{
		ptr2->state = OSC_STATE_END;
		ptr2++;
	}
	while(--i);

	//PWM
	PWM_DDR |= 1<<PWM_PIN;
	#if defined(__AVR_ATmega48__)		\
	 || defined(__AVR_ATmega88__)		\
	 || defined(__AVR_ATmega168__)		\
	 || defined(__AVR_ATmega328__)		\
	 || defined(__AVR_ATmega328P__)		\
	 || defined(__AVR_ATmega164__)		\
	 || defined(__AVR_ATmega324__)		\
	 || defined(__AVR_ATmega644__)
		#if defined(TIMER0)
			TCCR0A = (1<<COM0B1) | (1<<WGM01) | (1<<WGM00);
			TCCR0B = (1<<WGM02) | (1<<CS00);
			OCR0A = TOP_V;
			TIMSK0 |= 1<<OCE0B;
			#ifdef PWMA
				#error "PWMA kann nicht mit Timer0 genutzt werden!"
			#endif
		#elif defined(TIMER1)
			TCCR1B = (1<<WGM12) | (1<<WGM13) | (1<<CS10);
			ICR1 = TOP_V;
			#if defined(PWMA)
				TCCR1A = (1<<COM1A1) | (1<<WGM11);
				TIMSK1 = 1<<OCIE1A;
			#else
				TCCR1A = (1<<COM1B1) | (1<<WGM11);
				TIMSK1 = 1<<OCIE1B;
			#endif
		#elif defined(TIMER2)
			TCCR2A = (1<<COM2B1) | (1<<WG21) | (1<<WGM20);
			TCCR2B = (1<<WGM22) | (1<<CS20);
			OCR2A = TOP_V;
			TIMSK2 = 1<<OCE2B;
			#ifdef PWMA
				#error "PWMA kann nicht mit Timer2 genutzt werden!"
			#endif
		#endif	
 	#else
		#error "PWM Initialisierung nicht vorhanden!"
	#endif
	PWM_DDR |= 1<<PWM_PIN;
}

void synth_reset_oscs(uint8_t channels)
{
	uint8_t i = 0;
	do
	{
		if(i < channels)
		{
			synth.oscillators[i].state = OSC_STATE_DELAY;
			synth.oscillators[i].seq_data = 1;
		}
		else
		{
			synth.oscillators[i].state = OSC_STATE_END;
		}
		synth.oscillators[i].release = 255;
		synth.oscillators[i].temp = 10; //wird zu volume
		synth.oscillators[i].sound = 1*2;
	}	
	while(++i != CHANNELS);
}





