#ifndef SYNTHESIZER_H
#define SYNTHESIZER_H
#ifndef ONLY_DEFS

#include <avr/io.h>
#include <avr/pgmspace.h>
#include "Synth_config.h"

void synth_init(void);
void synth_load(uint16_t* data);
inline void synth_start(void)
{
	START_SYNTH();
}
inline void synth_stop(void)
{
	STOP_SYNTH();
}

extern uint16_t* Tones;
extern uint8_t* SoundInfo;
extern void synth_update(void);

typedef struct
{
	uint8_t state;
	uint16_t sustain_freq;
	uint16_t freq;
	uint16_t freqcounter;
	uint8_t sound;
	uint8_t volume;
	uint8_t release;
	uint8_t release_vel;				//Release-velocity
	uint16_t seq_data;
	uint8_t temp;
} __attribute__ ((packed)) Oscillator;

struct
{
	volatile uint8_t state, comp, ms_comp;
	uint8_t release_counter;
	uint16_t *read, *write;
	Oscillator oscillators[CHANNELS];
	uint16_t buffer[BUF_LEN]; 	
} __attribute__ ((packed)) synth;

void synth_reset_oscs(uint8_t channels);

#endif

//States
#define OSC_STATE_ATTACK		0
#define OSC_STATE_NOTE_ON		1
#define OSC_STATE_DELAY			2
#define OSC_STATE_END			3

#define SYNTH_STATE_MS			0		//Wird jede millisekunde gesetzt

//Offsets
#define OS_OSC_STATE			0
#define OS_OSC_SUSTAIN_FREQ		1
#define OS_OSC_FREQ				3
#define OS_OSC_FREQCNT			5
#define OS_OSC_SOUND			7
#define OS_OSC_VOLUME			8
#define OS_OSC_RELEASE			9
#define OS_OSC_RELEASE_VEL		10
#define OS_OSC_SEQ_DATA			11
#define OS_OSC_TEMP				13
#define OSC_LEN					14

#define OS_SYNTH_STATE			0
#define OS_SYNTH_COMP			1
#define OS_SYNTH_MS_COMP		2
#define OS_SYNTH_RELEASE_CNT	3
#define OS_SYNTH_READ			4
#define OS_SYNTH_WRITE			6
#define OS_SYNTH_OSCS			8
#define OS_SYNTH_BUFFER			(OS_SYNTH_OSCS + OSC_LEN * CHANNELS)
#define SYNTH_LEN				(OS_SYNTH_BUFFER + BUF_LEN*2)

#define SoundInfoLen 4

#endif
