//   Copyright (C) 2011-2012 Samuel Kleiser
//
//   This program is free software: you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation, either version 3 of the License, or
//   (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.


#include "avr/io.h"
#include "Synth_config.h"
#define ONLY_DEFS
#include "Synthesizer.h"
#undef ONLY_DEFS

.macro output a, b
	.if _SFR_IO_ADDR(\a) < 0x40
		out _SFR_IO_ADDR(\a), \b
	.else
		sts \a, \b
	.endif
.endm
.macro myjmp a
	.if FLASHEND > 0x1FFF
		jmp \a				//"-Wl,--relax" (Linker-option) ersetzt jmp zu rjmp wenn mglich
	.else
		rjmp \a
	.endif
.endm
.macro mycall a
	.if FLASHEND > 0x1FFF
		call \a				//"-Wl,--relax" (Linker-option) ersetzt call zu rcall wenn mglich
	.else
		rcall \a
	.endif
.endm

.extern synth

#if defined(TIMER0)
	#if defined(PWMA)
		.global TIMER0_COMPA_vect
		TIMER0_COMPA_vect:
	#else
		.global TIMER0_COMPB_vect
		TIMER0_COMPB_vect:
	#endif
#elif defined(TIMER1)
	#if defined(PWMA)
		.global TIMER1_COMPA_vect
		TIMER1_COMPA_vect:
	#else
		.global TIMER1_COMPB_vect
		TIMER1_COMPB_vect:
	#endif
#elif defined(TIMER2)
	#if defined(PWMA)
		.global TIMER2_COMPA_vect
		TIMER2_COMPA_vect:
	#else
		.global TIMER2_COMPB_vect
		TIMER2_COMPB_vect:
	#endif
#endif

	push 16
	in 16, _SFR_IO_ADDR(SREG)		//SREG sichern
	push YH
	push YL
	push 17

	lds YH, synth+OS_SYNTH_READ+1
	lds YL, synth+OS_SYNTH_READ

#if PWM_SIZE == 6
	adiw YL, 1
#if TIMER_SIZE > 8
	clr 17
	output PWM_REGH, 17
#endif
	ld 17, Y+
	lsr 17
	lsr 17
	output PWM_REGL, 17
#elif PWM_SIZE == 7
	adiw YL, 1
#if TIMER_SIZE > 8
	clr 17
	output PWM_REGH, 17
#endif
	ld 17, Y+
	lsr 17
	output PWM_REGL, 17
#elif PWM_SIZE == 8
	adiw YL, 1
#if TIMER_SIZE > 8
	clr 17
	output PWM_REGH, 17
#endif
	ld 17, Y+
	output PWM_REGL, 17
#elif PWM_SIZE == 9
	push 18
	ld 17, Y+
	lsl 17
	ld 18, Y+
	rol 18
	rol 17
	andi 17, 1
	output PWM_REGH, 17
	output PWM_REGL, 18
	pop 18
#elif PWM_SIZE == 10
	push 18
	ld 17, Y+
	ld 18, Y+
	lsl 17
	rol 18
	rol 17
	rol 18
	rol 17
	andi 17, 3
	output PWM_REGH, 17
	output PWM_REGL, 18
	pop 18
#elif PWM_SIZE == 11
	#error "Not implemented!"
#elif PWM_SIZE == 12
	#error "Not implemented!"
#endif
	lds 17, synth+OS_SYNTH_COMP
	cp 17, YL
	breq Synth_comp
	sts synth+OS_SYNTH_READ+1, YH
	sts synth+OS_SYNTH_READ, YL
Synth_comp_ret:
	pop 17
	pop YL
	pop YH
	out _SFR_IO_ADDR(SREG), 16		//SREG wiederherstellen
	pop 16
	reti


/**************************************************************
					Compare-Wert-Auswertung
**************************************************************/
Synth_comp:
	cpi YL, lo8(synth+OS_SYNTH_BUFFER+BUF_LEN*2)
	breq Synth_comp_buf		
	sts synth+OS_SYNTH_READ+1, YH
	sts synth+OS_SYNTH_READ, YL
Synth_comp_buf_ret:
	lds 17, synth+OS_SYNTH_MS_COMP
	cp 17, YL
	breq Synth_comp_ms
Synth_comp_ms_ret:
	mov YH, YL
	sub YL, 17
	subi YH, lo8(synth+OS_SYNTH_BUFFER+BUF_LEN*2)
	cp YH, YL
	brcc Synth_next_comp_buf
	sts synth+OS_SYNTH_COMP, 17
	rjmp Synth_comp_ret
Synth_next_comp_buf:
	ldi 17, lo8(synth+OS_SYNTH_BUFFER+BUF_LEN*2)
	sts synth+OS_SYNTH_COMP, 17
	rjmp Synth_comp_ret

Synth_comp_ms:
	subi 17, -MS_COMP
#if BUF_LEN*2 != 256
	brcc Synth_comp_ms_ovf
	cpi 17, lo8(BUF_LEN*2)
	brcc Synth_comp_ms_ovf
Synth_comp_ms_ovf_ret:
#endif
	sts synth+OS_SYNTH_MS_COMP, 17
	//MS-bit setzen
	lds YH, synth+OS_SYNTH_STATE
	ori YH, 1<<SYNTH_STATE_MS
	sts synth+OS_SYNTH_STATE, YH
	rjmp Synth_comp_ms_ret
#if BUF_LEN*2 != 256
Synth_comp_ms_ovf:
	subi 17, lo8(BUF_LEN*2)
	rjmp Synth_comp_ms_ovf_ret
#endif

Synth_comp_buf:
	ldi YH, hi8(synth+OS_SYNTH_BUFFER)			//Read-Pointer am Anfang
	ldi YL, lo8(synth+OS_SYNTH_BUFFER)
	sts synth+OS_SYNTH_READ+1, YH
	sts synth+OS_SYNTH_READ, YL
	rjmp Synth_comp_buf_ret



;*********************************************************
;Synthesizer Hauptroutine: Tonerzeugung
;Optimiert durch Nutzung aller Register und Aufrollen von Schleifen
;Deswegen leider schlecht lesbar, aber dafr eine unglaubliche Performance
;
;Programmablauf:
;1. Wenn nicht gengend Platz im Buffer ist return
;2. maximal 3 aktive Kanle in die Register laden
;4. BUF_LEN Samples berechnen und Buffer damit berschreiben
;5. Genderte Daten sichern (SRAM) 
;6. Sind alle Kanle berechnet return
;7. Schritt 2 wiederholen, ab sofort bei Schritt 4 die Sample zu dem Buffer addieren, statt ihn zu berschreiben

.global synth_update
.func synth_update

nullreg		= 2
nullreg2	= 3
sample		= 4
sample2		= 5
freqcnt1	= 6
freqcnt3	= 7
freqcnt5	= 8
bufwp_end	= 9
hrfreq1		= 10
hrfreq2		= 11
hrfreq3		= 12
hrfreq4		= 13
hrfreq5		= 14
hrfreq6		= 15
volsum1		= 16
volsum2		= 17
volsum3		= 18
temp		= 19
freqcnt2	= 20
sound1		= 21
freqcnt4	= 22
sound2		= 23
freqcnt6	= 24
sound3		= 25	

;Macros
.macro MR_LoadData1
	ldd 0, Z+OS_OSC_RELEASE
	mul 0, 0							;Decay Wert quadrieren
	ldd 0, Z+OS_OSC_VOLUME				
	mul 0, 1							;Errechneten Decaywert mit Volume multiplizieren
	mov volsum1, 1
	ldd freqcnt1, Z+OS_OSC_FREQCNT		;16bit Frequenzzhler laden
	ldd freqcnt2, Z+(OS_OSC_FREQCNT+1)
	ldd sound1, Z+OS_OSC_SOUND
	subi sound1, hi8(-(Sounds))
	ldd hrfreq1, Z+OS_OSC_FREQ			;16bit Schritt laden
	ldd hrfreq2, Z+(OS_OSC_FREQ+1)		;gleiche mit dem Highbyte
.endm
.macro MR_LoadData2
	ldd 0, Z+OS_OSC_RELEASE
	mul 0, 0
	ldd 0, Z+OS_OSC_VOLUME 
	mul 0, 1
	mov volsum2, 1
	ldd freqcnt3, Z+OS_OSC_FREQCNT		;16bit Frequenzzhler laden
	ldd freqcnt4, Z+(OS_OSC_FREQCNT+1)
	ldd sound2, Z+OS_OSC_SOUND
	subi sound2, hi8(-(Sounds))
	ldd hrfreq3, Z+OS_OSC_FREQ			;16bit Schritt laden
	ldd hrfreq4, Z+(OS_OSC_FREQ+1)		;gleiche mit dem Highbyte
.endm
.macro MR_LoadData3
	ldd 0, Z+OS_OSC_RELEASE
	mul 0, 0
	ldd 0, Z+OS_OSC_VOLUME
	mul 0, 1
	mov volsum3, 1
	ldd freqcnt5, Z+OS_OSC_FREQCNT			;16bit Frequenzzhler laden
	ldd freqcnt6, Z+(OS_OSC_FREQCNT+1)
	ldd sound3, Z+OS_OSC_SOUND
	subi sound3, hi8(-(Sounds))
	ldd hrfreq5, Z+OS_OSC_FREQ			;16bit Schritt laden
	ldd hrfreq6, Z+(OS_OSC_FREQ+1)		;gleiche mit dem Highbyte
.endm
.macro MR_Do1
	add freqcnt1, hrfreq1			;zum Zhler addieren
	adc freqcnt2, hrfreq2
	brcs 1f
4:

	;Tonerzeugung
	movw ZL, freqcnt2//:sound1
	lpm temp, Z

	;Lautstrke
	mulsu temp, volsum1

	add sample, 0
	adc sample2, 1
.endm
.macro MR_Do2
	add freqcnt3, hrfreq3			;zum Zhler addieren
	adc freqcnt4, hrfreq4
	brcs 2f
5:

	;Tonerzeugung
	movw ZL, freqcnt4//:sound2
	lpm temp, Z

	;Lautstrke
	mulsu temp, volsum2

	add sample, 0
	adc sample2, 1
.endm
.macro MR_Do3
	add freqcnt5, hrfreq5			;zum Zhler addieren
	adc freqcnt6, hrfreq6
	brcs 3f
6:

	;Tonerzeugung
	movw ZL, freqcnt6//:sound3
	lpm temp, Z

	;Lautstrke
	mulsu temp, volsum3

	add sample, 0
	adc sample2, 1
.endm
.macro MR_Do1_ovf dp
1:
	ldi temp, hi8(Sounds)
	sub temp, sound1
	sbrs temp, 0
	rjmp 7f
	cpi sound1, hi8(Sounds+NR_SAMPLE_START*256)
	brcs 4b
	in ZL, _SFR_IO_ADDR(SPL)
	in ZH, _SFR_IO_ADDR(SPH)
	ldd XL, Z+1+\dp
	ldd XH, Z+2+\dp
	ldi ZL, OSC_STATE_DELAY
#if OS_OSC_STATE != 0
	#error "OS_OSC_STATE muss den Index 0 besitzen!"
#endif
	st X, ZL
	clr volsum1
	rjmp 4b
.endm
.macro MR_Do1_ovf2 dp
7:
	inc sound1
	in ZL, _SFR_IO_ADDR(SPL)
	in ZH, _SFR_IO_ADDR(SPH)
	ldd XL, Z+1+\dp
	ldd XH, Z+2+\dp
	movw ZL, XL
	ldd hrfreq1, Z+OS_OSC_SUSTAIN_FREQ
	ldd hrfreq2, Z+OS_OSC_SUSTAIN_FREQ+1	
	std Z+OS_OSC_FREQ, hrfreq1
	std Z+OS_OSC_FREQ+1, hrfreq2
	subi sound1, hi8(Sounds)
	std Z+OS_OSC_SOUND, sound1
	subi sound1, hi8(-(Sounds))
	rjmp 4b
.endm
.macro MR_Do2_ovf dp
2:
	ldi temp, hi8(Sounds)
	sub temp, sound2
	sbrs temp, 0
	rjmp 8f
	cpi sound2, hi8(Sounds+NR_SAMPLE_START*256)
	brcs 5b
	in ZL, _SFR_IO_ADDR(SPL)
	in ZH, _SFR_IO_ADDR(SPH)
	ldd XL, Z+1+\dp
	ldd XH, Z+2+\dp
	ldi ZL, OSC_STATE_DELAY
#if OS_OSC_STATE != 0
	#error "OS_OSC_STATE muss den Index 0 besitzen!"
#endif
	st X, ZL
	clr volsum2
	rjmp 5b
.endm
.macro MR_Do2_ovf2 dp
8:
	inc sound2
	in ZL, _SFR_IO_ADDR(SPL)
	in ZH, _SFR_IO_ADDR(SPH)
	ldd XL, Z+1+\dp
	ldd XH, Z+2+\dp
	movw ZL, XL
	ldd hrfreq3, Z+OS_OSC_SUSTAIN_FREQ
	ldd hrfreq4, Z+OS_OSC_SUSTAIN_FREQ+1	
	std Z+OS_OSC_FREQ, hrfreq3
	std Z+OS_OSC_FREQ+1, hrfreq4
	subi sound2, hi8(Sounds)
	std Z+OS_OSC_SOUND, sound2
	subi sound2, hi8(-(Sounds))
	rjmp 5b
.endm
.macro MR_Do3_ovf dp
3:
	ldi temp, hi8(Sounds)
	sub temp, sound3
	sbrs temp, 0
	rjmp 9f
	cpi sound3, hi8(Sounds+NR_SAMPLE_START*256)
	brcs 6b
	in ZL, _SFR_IO_ADDR(SPL)
	in ZH, _SFR_IO_ADDR(SPH)
	ldd XL, Z+1+\dp
	ldd XH, Z+2+\dp
	ldi ZL, OSC_STATE_DELAY
#if OS_OSC_STATE != 0
	#error "OS_OSC_STATE muss den Index 0 besitzen!"
#endif
	st X, ZL
	clr volsum3
	rjmp 6b
.endm
.macro MR_Do3_ovf2 dp
9:
	inc sound3
	in ZL, _SFR_IO_ADDR(SPL)
	in ZH, _SFR_IO_ADDR(SPH)
	ldd XL, Z+1+\dp
	ldd XH, Z+2+\dp
	movw ZL, XL
	ldd hrfreq5, Z+OS_OSC_SUSTAIN_FREQ
	ldd hrfreq6, Z+OS_OSC_SUSTAIN_FREQ+1	
	std Z+OS_OSC_FREQ, hrfreq5
	std Z+OS_OSC_FREQ+1, hrfreq6
	subi sound3, hi8(Sounds)
	std Z+OS_OSC_SOUND, sound3
	subi sound3, hi8(-(Sounds))
	rjmp 6b
.endm

Synth_ms_update:
	andi 18, ~(1<<SYNTH_STATE_MS)		//Bit lschen
	sts synth+OS_SYNTH_STATE, 18
#ifdef MSEC_CFUNC1
	mycall MSEC_CFUNC1
#endif
#ifdef MSEC_CFUNC2
	mycall MSEC_CFUNC2
#endif
#ifdef MSEC_CFUNC2
	mycall MSEC_CFUNC2
#endif
;----------------------Decay---------------------
	lds 18, synth+OS_SYNTH_RELEASE_CNT
	dec 18
	breq Release_init
	sts synth+OS_SYNTH_RELEASE_CNT, 18
	rjmp Synth_ms_update_ret
Release_init:
	ldi 18, RELEASE_PRESCALER
	sts synth+OS_SYNTH_RELEASE_CNT, 18
	ldi ZH, hi8(synth+OS_SYNTH_OSCS)	//Z-Pointer auf Oscillator-Array setzen
	ldi ZL, lo8(synth+OS_SYNTH_OSCS)
	ldi 19, CHANNELS
	rjmp Release_start
Release_loop:
	dec 19
	breq Synth_ms_update_ret
	adiw ZL, OSC_LEN
Release_start:	
	ldd 0, Z+OS_OSC_RELEASE_VEL
	tst 0
	breq Release_loop
	ldd 18, Z+OS_OSC_STATE
	cpi 18, OSC_STATE_ATTACK
	breq Attack
	cpi 18, OSC_STATE_NOTE_ON
	brne Release_loop
	ldd 18, Z+OS_OSC_RELEASE
	sub 18, 0
	std Z+OS_OSC_RELEASE, 18
	brcc Release_loop
	ldi 18, OSC_STATE_DELAY
	std Z+OS_OSC_STATE, 18				//Volume = 0 -> Ton muss nicht mehr berechnet werden
	rjmp Release_loop
Attack:
	ldd 18, Z+OS_OSC_RELEASE
	add 18, 0
	std Z+OS_OSC_RELEASE, 18
	brcc Release_loop
	ldi 18, OSC_STATE_NOTE_ON
	std Z+OS_OSC_STATE, 18
	ldi 18, 255
	std Z+OS_OSC_RELEASE, 18
	//Neuer Abklinggeschw. laden
	movw 22, ZL
.if SoundInfoLen != 4
	.error "Asm Code ist auf SoundInfoLen==4 ausgelegt!"
.endif
	ldd ZL, Z+OS_OSC_SOUND
	andi ZL, 254
	lsl ZL
	ldi ZH, hi8(SoundInfo)
	subi ZL, 3
	lpm 18, Z
	movw ZL, 22
	std Z+OS_OSC_RELEASE_VEL, 18
	rjmp Release_loop
;Kein Kanal verarbeiten / Buffer leeren
MR_Start0:	
	st Y+, nullreg		//nullreg:nullreg2 enthlt hier 0x8000
	st Y+, nullreg2
	cp YL, bufwp_end
	brne MR_Start0
	rjmp MR_End
;Initialisierung
;--------------------EINSTIEG--------------------
synth_update:
	lds 18, synth+OS_SYNTH_STATE
	sbrc 18, SYNTH_STATE_MS
	rjmp Synth_ms_update
Synth_ms_update_ret:
	lds 18, synth+OS_SYNTH_READ
	lds 19, synth+OS_SYNTH_WRITE
	sub 18, 19
	cpi 18, BUF_LEN		//Lnge in Words = Halbe Lnge in Bytes
	brcc Update_Start
	ret
Update_Start:
	push 2
	push 3
	push 4
	push 5
	push 6
	push 7
	push 8
	push 9
	push 10
	push 11
	push 12
	push 13
	push 14
	push 15
	push 16
	push 17
	push 28
	push 29

	mov YL, 19
	lds YH, synth+OS_SYNTH_WRITE+1
	
	cpi YL, lo8(synth+OS_SYNTH_BUFFER+BUF_LEN)
	brne Update2
	ldi ZH, hi8(synth+OS_SYNTH_BUFFER)			//Neuen Schreibpointer speichern
	ldi ZL, lo8(synth+OS_SYNTH_BUFFER)
	rjmp Update3 
Update2:
	ldi ZH, hi8(synth+OS_SYNTH_BUFFER+BUF_LEN)	//Neuen Schreibpointer speichern
	ldi ZL, lo8(synth+OS_SYNTH_BUFFER+BUF_LEN)
Update3:
	sts synth+OS_SYNTH_WRITE, ZL
	sts synth+OS_SYNTH_WRITE+1, ZH

	//Und los gehts....
	//Startwerte setzen fr Hauptroutine
	ldi ZH, hi8(synth+OS_SYNTH_OSCS)	//Z-Pointer auf Oscillator-Array setzen
	ldi ZL, lo8(synth+OS_SYNTH_OSCS)
	//Nullregister auf 0x8000 setzen 
	ldi 16, 0x80
	mov nullreg2, 16
	clr nullreg

	mov bufwp_end, YL
	ldi XL, BUF_LEN
	add bufwp_end, XL		//Endposition des Schreibpointers X

	ldi XL, CHANNELS
	rjmp MR_Load
;Register mit Daten laden
MR_Next1:
	adiw ZL, OSC_LEN
	dec XL
	breq MR_Start0
	;Prfen
MR_Load:
	ldd temp, Z+OS_OSC_STATE			;Statusbyte der Spur laden
	cpi temp, OSC_STATE_DELAY	;Wenn die Spur eine Pause enthlt
	brsh MR_Next1				;nchste Spur berechnen, brsh, da die Spur auch zu Ende sein knnte
	MR_LoadData1
	push ZH
	push ZL
MR_Next2:
	adiw ZL, OSC_LEN
	dec XL
	breq MR_Start1
	;Prfen
	ldd temp, Z+OS_OSC_STATE			;Statusbyte der Spur laden
	cpi temp, OSC_STATE_DELAY	;Wenn die Spur eine Pause enthlt
	brsh MR_Next2				;nchste Spur berechnen, brsh, da die Spur auch zu Ende sein knnte
	MR_LoadData2
	push ZH
	push ZL
MR_Next3:
	adiw ZL, OSC_LEN
	dec XL
	breq MR_Start2
	;Prfen
	ldd temp, Z+OS_OSC_STATE			;Statusbyte der Spur laden
	cpi temp, OSC_STATE_DELAY	;Wenn die Spur eine Pause enthlt
	brsh MR_Next3				;nchste Spur berechnen, brsh, da die Spur auch zu Ende sein knnte
	MR_LoadData3
	push ZH
	push ZL
	rjmp MR_Start3

;1 Kanal verarbeiten
MR_Start1:
MR_Loop1:	
	movw sample/*:sample2*/, nullreg//:nullreg2	;Altes Sample lschen	

	MR_Do1
	
	st Y+, sample
	st Y+, sample2
	cp YL, bufwp_end
	brne MR_Loop1
	
	clt

	rjmp MR_Store1
MR_Do1_ovf 0
MR_Do1_ovf2 0

;2 Kanle verarbeiten	
MR_Start2:
MR_Loop2:	
	movw sample/*:sample2*/, nullreg//:nullreg2	;Altes Sample lschen	

	MR_Do1
	MR_Do2
	
	st Y+, sample
	st Y+, sample2
	cp YL, bufwp_end
	brne MR_Loop2

	clt

	rjmp MR_Store2
	MR_Do1_ovf 2
	MR_Do2_ovf 0
	MR_Do1_ovf2 2
	MR_Do2_ovf2 0

;3 Kanle verarbeiten
MR_Start3:
MR_Loop3:	
	movw sample/*:sample2*/, nullreg//:nullreg2	;Altes Sample lschen	
	
	MR_Do1
	MR_Do2
	MR_Do3
	
	st Y+, sample
	st Y+, sample2
	cp YL, bufwp_end
	brne MR_Loop3
	
	set

	rjmp MR_Store3
	MR_Do1_ovf 4
	MR_Do2_ovf 2
	MR_Do3_ovf 0
	MR_Do1_ovf2 4
	MR_Do2_ovf2 2
	MR_Do3_ovf2 0
/*1:
	ori sound1, 1
	rjmp 4b
2:
	ori sound2, 1
	rjmp 5b
3:
	ori sound3, 1
	rjmp 6b*/

;Ende
MR_End:
	pop 29
	pop 28
	pop 17
	pop 16
	pop 15
	pop 14
	pop 13
	pop 12
	pop 11
	pop 10
	pop 9
	pop 8
	pop 7
	pop 6
	pop 5
	pop 4
	pop 3
	pop 2
	clr 1
	ret			;Routine fertig, zurck springen
;Relevante Daten in SRAM zurckschreiben
MR_Store3:						;Frequenzzhler speichern
	pop ZL
	pop ZH
	movw XL, ZL
	std Z+OS_OSC_FREQCNT, freqcnt5
	std Z+OS_OSC_FREQCNT+1, freqcnt6
	//subi sound3, hi8(Sounds)
MR_Store2:
	pop ZL
	pop ZH
	std Z+OS_OSC_FREQCNT, freqcnt3	
	std Z+OS_OSC_FREQCNT+1, freqcnt4
	//subi sound2, hi8(Sounds)
MR_Store1:						;siehe MR_Store2
	pop ZL
	pop ZH
	std Z+OS_OSC_FREQCNT, freqcnt1	
	std Z+OS_OSC_FREQCNT+1, freqcnt2
	//subi sound1, hi8(Sounds)

	brtc MR_End					;Das war der letzte Kanal
	//Es sind noch weitere Kanle vorhanden
	movw ZL, XL					;Z wiederherstellen
	subi YL, lo8(BUF_LEN)
	sbci YH, hi8(BUF_LEN)
	ldi XL, hi8(synth+OS_SYNTH_OSCS+OSC_LEN*CHANNELS)	//cpc Compare Wert
;Register mit Daten laden
MR_NextA1:
	adiw ZL, OSC_LEN
	cpi ZL, lo8(synth+OS_SYNTH_OSCS+OSC_LEN*CHANNELS)
	cpc ZH, XL
	breq MR_End
	;Prfen
	ldd temp, Z+OS_OSC_STATE			;Statusbyte der Spur laden
	cpi temp, OSC_STATE_DELAY	;Wenn die Spur eine Pause enthlt
	brsh MR_NextA1				;nchste Spur berechnen, brsh, da die Spur auch zu Ende sein knnte
	MR_LoadData1
	push ZH
	push ZL
MR_NextA2:
	adiw ZL, OSC_LEN
	cpi ZL, lo8(synth+OS_SYNTH_OSCS+OSC_LEN*CHANNELS)
	cpc ZH, XL
	breq MR_StartA1
	;Prfen
	ldd temp, Z+OS_OSC_STATE			;Statusbyte der Spur laden
	cpi temp, OSC_STATE_DELAY	;Wenn die Spur eine Pause enthlt
	brsh MR_NextA2				;nchste Spur berechnen, brsh, da die Spur auch zu Ende sein knnte
	MR_LoadData2
	push ZH
	push ZL
MR_NextA3:
	adiw ZL, OSC_LEN
	cpi ZL, lo8(synth+OS_SYNTH_OSCS+OSC_LEN*CHANNELS)
	cpc ZH, XL
	breq MR_StartA2
	;Prfen
	ldd temp, Z+OS_OSC_STATE			;Statusbyte der Spur laden
	cpi temp, OSC_STATE_DELAY	;Wenn die Spur eine Pause enthlt
	brsh MR_NextA3				;nchste Spur berechnen, brsh, da die Spur auch zu Ende sein knnte
	MR_LoadData3
	push ZH
	push ZL
	rjmp MR_StartA3

;1 Kanal...
MR_StartA1:
MR_LoopA1:	
	ldd sample2, Y+1
	ld sample, Y

	MR_Do1
	
	st Y+, sample
	st Y+, sample2
	cp YL, bufwp_end
	brne MR_LoopA1
	
	clt

	rjmp MR_Store1
	MR_Do1_ovf 0
	MR_Do1_ovf2 0

;2 Kanle...
MR_StartA2:
MR_LoopA2:	
	ldd sample2, Y+1
	ld sample, Y

	MR_Do1
	MR_Do2
	
	st Y+, sample
	st Y+, sample2
	cp YL, bufwp_end
	brne MR_LoopA2

	clt

	rjmp MR_Store2	
	MR_Do1_ovf 2
	MR_Do2_ovf 0
	MR_Do1_ovf2 2
	MR_Do2_ovf2 0

;3 Kanle verarbeiten und zu Buffer addieren
MR_StartA3:
MR_LoopA3:	
	ldd sample2, Y+1
	ld sample, Y
	
	MR_Do1
	MR_Do2
	MR_Do3
	
	st Y+, sample
	st Y+, sample2
	cp YL, bufwp_end
	brne MR_LoopA3

	set
	
	rjmp MR_Store3
	MR_Do1_ovf 4
	MR_Do2_ovf 2
	MR_Do3_ovf 0
	MR_Do1_ovf2 4
	MR_Do2_ovf2 2
	MR_Do3_ovf2 0

.endfunc

	
.section .progmem.data
.p2align 8
;****************************************************
;
;Diese Tabelle hngt sich an die nchsten x00-xFF Bytes des Flashs dran.
;
;
;Tontabelle
;
;Vorberechnete Tabelle:
;	freq * 65536 / SAMPLE_FREQ
;
.global Tones
Tones:
;								C							Cis/Des							D							Dis/Es							E							F							Fis/Ges							G							Gis/As							A							B/Ais							H


.word         535809 / SAMPLE_FREQ,         567670 / SAMPLE_FREQ,         601425 / SAMPLE_FREQ,         637188 / SAMPLE_FREQ,         675077 / SAMPLE_FREQ,         715219 / SAMPLE_FREQ,         757749 / SAMPLE_FREQ,         802807 / SAMPLE_FREQ,         850544 / SAMPLE_FREQ,         901120 / SAMPLE_FREQ,         954703 / SAMPLE_FREQ,        1011473 / SAMPLE_FREQ
.word        1071618 / SAMPLE_FREQ,        1135340 / SAMPLE_FREQ,        1202851 / SAMPLE_FREQ,        1274376 / SAMPLE_FREQ,        1350154 / SAMPLE_FREQ,        1430439 / SAMPLE_FREQ,        1515497 / SAMPLE_FREQ,        1605613 / SAMPLE_FREQ,        1701088 / SAMPLE_FREQ,        1802240 / SAMPLE_FREQ,        1909407 / SAMPLE_FREQ,        2022946 / SAMPLE_FREQ
.word        2143237 / SAMPLE_FREQ,        2270680 / SAMPLE_FREQ,        2405702 / SAMPLE_FREQ,        2548752 / SAMPLE_FREQ,        2700309 / SAMPLE_FREQ,        2860878 / SAMPLE_FREQ,        3030994 / SAMPLE_FREQ,        3211227 / SAMPLE_FREQ,        3402176 / SAMPLE_FREQ,        3604480 / SAMPLE_FREQ,        3818814 / SAMPLE_FREQ,        4045892 / SAMPLE_FREQ
.word        4286473 / SAMPLE_FREQ,        4541360 / SAMPLE_FREQ,        4811404 / SAMPLE_FREQ,        5097505 / SAMPLE_FREQ,        5400618 / SAMPLE_FREQ,        5721755 / SAMPLE_FREQ,        6061989 / SAMPLE_FREQ,        6422453 / SAMPLE_FREQ,        6804352 / SAMPLE_FREQ,        7208960 / SAMPLE_FREQ,        7637627 / SAMPLE_FREQ,        8091784 / SAMPLE_FREQ
.word        8572947 / SAMPLE_FREQ,        9082720 / SAMPLE_FREQ,        9622807 / SAMPLE_FREQ,       10195009 / SAMPLE_FREQ,       10801236 / SAMPLE_FREQ,       11443511 / SAMPLE_FREQ,       12123977 / SAMPLE_FREQ,       12844906 / SAMPLE_FREQ,       13608704 / SAMPLE_FREQ,       14417920 / SAMPLE_FREQ,       15275254 / SAMPLE_FREQ,       16183568 / SAMPLE_FREQ
.word       17145893 / SAMPLE_FREQ,       18165441 / SAMPLE_FREQ,       19245614 / SAMPLE_FREQ,       20390018 / SAMPLE_FREQ,       21602472 / SAMPLE_FREQ,       22887021 / SAMPLE_FREQ,       24247954 / SAMPLE_FREQ,       25689813 / SAMPLE_FREQ,       27217409 / SAMPLE_FREQ,       28835840 / SAMPLE_FREQ,       30550508 / SAMPLE_FREQ,       32367136 / SAMPLE_FREQ
.word       34291786 / SAMPLE_FREQ,       36330882 / SAMPLE_FREQ,       38491228 / SAMPLE_FREQ,       40780036 / SAMPLE_FREQ,       43204943 / SAMPLE_FREQ,       45774043 / SAMPLE_FREQ,       48495909 / SAMPLE_FREQ,       51379626 / SAMPLE_FREQ,       54434817 / SAMPLE_FREQ,       57671680 / SAMPLE_FREQ,       61101017 / SAMPLE_FREQ,       64734272 / SAMPLE_FREQ
.word       68583572 / SAMPLE_FREQ,       72661764 / SAMPLE_FREQ,       76982457 / SAMPLE_FREQ,       81560072 / SAMPLE_FREQ,       86409886 / SAMPLE_FREQ,       91548086 / SAMPLE_FREQ,       96991818 / SAMPLE_FREQ,      102759252 / SAMPLE_FREQ,      108869635 / SAMPLE_FREQ,      115343360 / SAMPLE_FREQ,      122202033 / SAMPLE_FREQ,      129468544 / SAMPLE_FREQ
.word      137167144 / SAMPLE_FREQ,      145323527 / SAMPLE_FREQ,      153964914 / SAMPLE_FREQ,      163120144 / SAMPLE_FREQ,      172819773 / SAMPLE_FREQ,      183096171 / SAMPLE_FREQ,      193983636 / SAMPLE_FREQ,      205518503 / SAMPLE_FREQ,      217739269 / SAMPLE_FREQ,      230686720 / SAMPLE_FREQ,      244404066 / SAMPLE_FREQ,      258937088 / SAMPLE_FREQ
.word      274334289 / SAMPLE_FREQ,      290647054 / SAMPLE_FREQ,      307929828 / SAMPLE_FREQ,      326240288 / SAMPLE_FREQ,      345639545 / SAMPLE_FREQ,      366192342 / SAMPLE_FREQ,      387967272 / SAMPLE_FREQ,      411037006 / SAMPLE_FREQ,      435478539 / SAMPLE_FREQ,      461373440 / SAMPLE_FREQ,      488808132 / SAMPLE_FREQ,      517874176 / SAMPLE_FREQ
.word      548668578 / SAMPLE_FREQ,      581294109 / SAMPLE_FREQ,      615859655 / SAMPLE_FREQ,      652480576 / SAMPLE_FREQ,      691279090 / SAMPLE_FREQ,      732384684 / SAMPLE_FREQ,      775934544 / SAMPLE_FREQ,      822074013 / SAMPLE_FREQ

;Instrumente
;
;a) Instrumente, die einen kleineren Index als NR_SAMPLE_START besitzen
;	enthalten ein 256Byte groes Attack-Sample. Nach dem Spielen dieses Samples
;	wird das folgende Sustainsample (256Byte) wiederholt, bis der Ton zu Ende ist
;	oder der Ton durch die Hllkurve ausgeklungen ist. Die Geschwindigkeit der beiden
;	Samples lsst sich durch einen Teiler individuell bestimmen. Dieser wird in der
;	SoundInfo-Tabelle fr jedes Instrument einzeln festlegt (unten). Diese Tabelle
;	erlaubt auch das Einstellen einer Attack und Decay-Hllkurve.
;b) Instrumente die einen greren oder gleichgroen Index wie NR_SAMPLE_START besitzen
;	werden nur einmal als 512Byte Sample wiedergegeben. Dies eigent sich vorallem fr
;	Schlaginstrumente. Die SoundInfo-"Effekte" sind trotzdem aktiv.
;
;Der Index jedes Instrumentes ist das Highbyte der Adresse vom Sounds-Label aus.
;Darum ist auch jeder Index gerade, da die ungerade in die Mitte der 512Byte
;Datenstze zeigen.

Sounds:
;Musicbox
;Attack
.byte 0x00, 0xff, 0xfd, 0xff, 0x00, 0xff, 0xfd, 0xfd, 0x00, 0x00, 0xff, 0xfd, 0x00, 0x05, 0x03, 0xfe
.byte 0xfd, 0x01, 0x02, 0xfa, 0xee, 0xf0, 0x01, 0x14, 0x17, 0x0d, 0x06, 0x0a, 0x12, 0x14, 0x12, 0x13
.byte 0x1a, 0x1b, 0x11, 0x00, 0xf4, 0xf5, 0xff, 0x06, 0x00, 0xeb, 0xd0, 0xbe, 0xb9, 0xba, 0xb5, 0xb0
.byte 0xbb, 0xda, 0xfe, 0x15, 0x1e, 0x28, 0x37, 0x3e, 0x31, 0x1b, 0x15, 0x2a, 0x48, 0x59, 0x57, 0x4f
.byte 0x49, 0x42, 0x30, 0x16, 0x00, 0xf2, 0xea, 0xe4, 0xe1, 0xde, 0xdb, 0xd4, 0xc7, 0xb3, 0x9a, 0x87
.byte 0x87, 0x9d, 0xbc, 0xd0, 0xd5, 0xd7, 0xdf, 0xea, 0xf0, 0xf4, 0x02, 0x22, 0x43, 0x54, 0x56, 0x55
.byte 0x56, 0x54, 0x49, 0x3c, 0x39, 0x42, 0x4f, 0x59, 0x5c, 0x56, 0x3f, 0x18, 0xed, 0xce, 0xc0, 0xbc
.byte 0xbd, 0xc3, 0xd2, 0xe0, 0xe4, 0xd9, 0xc8, 0xb6, 0xa6, 0x98, 0x94, 0x9e, 0xb4, 0xcf, 0xe8, 0xff
.byte 0x10, 0x16, 0x0e, 0x01, 0xfd, 0x01, 0x0c, 0x18, 0x28, 0x40, 0x59, 0x69, 0x6c, 0x67, 0x62, 0x5a
.byte 0x4f, 0x42, 0x38, 0x34, 0x30, 0x2a, 0x22, 0x18, 0x0a, 0xf4, 0xd9, 0xbf, 0xab, 0x9d, 0x93, 0x90
.byte 0x92, 0x96, 0x98, 0x9b, 0xa2, 0xae, 0xb8, 0xbf, 0xc6, 0xd4, 0xe8, 0xfc, 0x0a, 0x17, 0x26, 0x36
.byte 0x43, 0x4b, 0x51, 0x58, 0x60, 0x67, 0x6d, 0x70, 0x6f, 0x68, 0x5c, 0x4f, 0x41, 0x31, 0x1e, 0x0c
.byte 0x00, 0xf8, 0xef, 0xe4, 0xd6, 0xc9, 0xbd, 0xb1, 0xa8, 0xa1, 0x9c, 0x99, 0x98, 0x9d, 0xa7, 0xb0
.byte 0xb5, 0xb8, 0xbc, 0xc5, 0xd0, 0xdd, 0xee, 0x03, 0x1b, 0x30, 0x3f, 0x4b, 0x56, 0x5e, 0x61, 0x63
.byte 0x67, 0x6e, 0x73, 0x71, 0x67, 0x5b, 0x4f, 0x41, 0x2f, 0x1d, 0x0e, 0x04, 0xfb, 0xed, 0xdb, 0xc8
.byte 0xb7, 0xa8, 0x9b, 0x90, 0x89, 0x88, 0x8c, 0x93, 0x9b, 0xa2, 0xab, 0xb6, 0xc2, 0xcf, 0xdb, 0xea
;Sustain
.byte 0x00, 0x02, 0x05, 0x08, 0x0b, 0x0e, 0x11, 0x14, 0x17, 0x19, 0x1c, 0x1f, 0x22, 0x25, 0x27, 0x2a
.byte 0x2d, 0x2f, 0x32, 0x34, 0x37, 0x39, 0x3c, 0x3e, 0x41, 0x43, 0x45, 0x47, 0x4a, 0x4c, 0x4e, 0x50
.byte 0x52, 0x53, 0x55, 0x57, 0x59, 0x5a, 0x5c, 0x5d, 0x5f, 0x60, 0x62, 0x63, 0x64, 0x65, 0x66, 0x67
.byte 0x68, 0x69, 0x6a, 0x6b, 0x6b, 0x6c, 0x6d, 0x6d, 0x6d, 0x6e, 0x6e, 0x6e, 0x6e, 0x6f, 0x6f, 0x6f
.byte 0x6e, 0x6e, 0x6e, 0x6e, 0x6d, 0x6d, 0x6c, 0x6c, 0x6b, 0x6b, 0x6a, 0x69, 0x68, 0x67, 0x66, 0x65
.byte 0x64, 0x63, 0x62, 0x61, 0x5f, 0x5e, 0x5d, 0x5b, 0x5a, 0x58, 0x57, 0x55, 0x53, 0x51, 0x50, 0x4e
.byte 0x4c, 0x4a, 0x48, 0x46, 0x44, 0x42, 0x40, 0x3e, 0x3b, 0x39, 0x37, 0x35, 0x32, 0x30, 0x2e, 0x2b
.byte 0x29, 0x26, 0x24, 0x21, 0x1f, 0x1c, 0x1a, 0x17, 0x15, 0x12, 0x0f, 0x0d, 0x0a, 0x07, 0x05, 0x02
.byte 0x00, 0xfe, 0xfb, 0xf9, 0xf6, 0xf3, 0xf1, 0xee, 0xeb, 0xe9, 0xe6, 0xe4, 0xe1, 0xdf, 0xdc, 0xda
.byte 0xd7, 0xd5, 0xd2, 0xd0, 0xce, 0xcb, 0xc9, 0xc7, 0xc5, 0xc2, 0xc0, 0xbe, 0xbc, 0xba, 0xb8, 0xb6
.byte 0xb4, 0xb2, 0xb0, 0xaf, 0xad, 0xab, 0xa9, 0xa8, 0xa6, 0xa5, 0xa3, 0xa2, 0xa1, 0x9f, 0x9e, 0x9d
.byte 0x9c, 0x9b, 0x9a, 0x99, 0x98, 0x97, 0x96, 0x95, 0x95, 0x94, 0x94, 0x93, 0x93, 0x92, 0x92, 0x92
.byte 0x92, 0x92, 0x91, 0x91, 0x92, 0x92, 0x92, 0x92, 0x93, 0x93, 0x93, 0x94, 0x95, 0x95, 0x96, 0x97
.byte 0x98, 0x99, 0x9a, 0x9b, 0x9c, 0x9d, 0x9e, 0xa0, 0xa1, 0xa3, 0xa4, 0xa6, 0xa7, 0xa9, 0xab, 0xad
.byte 0xae, 0xb0, 0xb2, 0xb4, 0xb6, 0xb9, 0xbb, 0xbd, 0xbf, 0xc2, 0xc4, 0xc7, 0xc9, 0xcc, 0xce, 0xd1
.byte 0xd3, 0xd6, 0xd9, 0xdb, 0xde, 0xe1, 0xe4, 0xe6, 0xe9, 0xec, 0xef, 0xf2, 0xf5, 0xf8, 0xfb, 0xfe
;Harpsichord
.byte 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
.byte 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xfd, 0x00, 0x00, 0x01, 0x05, 0x05, 0x05, 0x10, 0x0d, 0x06
.byte 0x05, 0xfb, 0xfb, 0xff, 0x02, 0x0a, 0x0f, 0x02, 0xfd, 0xfa, 0xf1, 0xf4, 0xf0, 0xd6, 0xe7, 0xf3
.byte 0xef, 0x01, 0x17, 0x01, 0x03, 0x00, 0xda, 0xdf, 0xf3, 0xdd, 0x03, 0x40, 0x46, 0x4f, 0x2b, 0x08
.byte 0xf9, 0x01, 0xf5, 0x17, 0x1d, 0x1a, 0x11, 0x22, 0xf3, 0xdd, 0xe5, 0xd2, 0xd3, 0xda, 0xe7, 0x0c
.byte 0x23, 0x25, 0x25, 0xf7, 0xe3, 0xe3, 0xdc, 0xe4, 0x0b, 0x16, 0x09, 0xfb, 0xf4, 0xf6, 0x1f, 0x0e
.byte 0xf8, 0xf3, 0xfc, 0x10, 0x0f, 0xee, 0xca, 0xd3, 0xd4, 0xf8, 0xf8, 0x22, 0x50, 0x77, 0x7a, 0x47
.byte 0xf1, 0xb9, 0xb9, 0xc9, 0xdd, 0x0c, 0x39, 0x32, 0x3e, 0x16, 0xdf, 0xd4, 0xda, 0xca, 0xca, 0xab
.byte 0xbb, 0x09, 0x29, 0x27, 0x34, 0xf6, 0xd6, 0xea, 0xd3, 0xc6, 0xde, 0xfc, 0x09, 0x22, 0xff, 0xf2
.byte 0xfe, 0x25, 0x25, 0x03, 0xfc, 0xf0, 0xfa, 0x0a, 0xf2, 0xd9, 0xdd, 0xe7, 0x0a, 0x21, 0x43, 0x5c
.byte 0x79, 0x7a, 0x52, 0xff, 0xcb, 0xb6, 0xaf, 0xdb, 0x0d, 0x21, 0x41, 0x40, 0x10, 0x03, 0xe7, 0xda
.byte 0xd2, 0x9f, 0x84, 0xad, 0xd4, 0x17, 0x37, 0x27, 0x10, 0xff, 0xf2, 0xdd, 0xd2, 0xe9, 0x0a, 0x08
.byte 0x11, 0xea, 0xee, 0x12, 0x28, 0x10, 0x01, 0xfb, 0xeb, 0x03, 0x03, 0xf0, 0xe6, 0xef, 0xfb, 0x0a
.byte 0x08, 0x18, 0x4a, 0x7a, 0x72, 0x26, 0xf9, 0xd1, 0xa2, 0xd1, 0xe3, 0x06, 0x35, 0x41, 0x3a, 0x25
.byte 0x00, 0x02, 0x04, 0xe6, 0xc4, 0x99, 0xb8, 0xe5, 0x18, 0x2a, 0x16, 0x04, 0x06, 0xfc, 0xe2, 0xe8
.byte 0xe7, 0xf0, 0xf9, 0xea, 0xc5, 0xe3, 0x0d, 0x16, 0x13, 0x00, 0xe8, 0xee, 0x07, 0xfa, 0xed, 0xec
.byte 0x00, 0x02, 0x09, 0x0f, 0x16, 0x21, 0x2d, 0x35, 0x3e, 0x47, 0x4d, 0x54, 0x5b, 0x60, 0x65, 0x69
.byte 0x6c, 0x6f, 0x73, 0x75, 0x76, 0x74, 0x6f, 0x69, 0x63, 0x5b, 0x53, 0x4d, 0x45, 0x39, 0x2e, 0x1f
.byte 0x12, 0x08, 0x01, 0xfb, 0xf2, 0xec, 0xe7, 0xe6, 0xe7, 0xe6, 0xe5, 0xe2, 0xe1, 0xe2, 0xe4, 0xe7
.byte 0xeb, 0xeb, 0xea, 0xe6, 0xe3, 0xe1, 0xdf, 0xde, 0xdd, 0xdd, 0xde, 0xe0, 0xe2, 0xe6, 0xeb, 0xf1
.byte 0xf8, 0xfe, 0x03, 0x07, 0x0c, 0x13, 0x19, 0x21, 0x27, 0x2c, 0x2f, 0x33, 0x37, 0x3a, 0x3e, 0x41
.byte 0x43, 0x44, 0x42, 0x3f, 0x3d, 0x3a, 0x37, 0x33, 0x2e, 0x28, 0x22, 0x1b, 0x15, 0x10, 0x0a, 0x00
.byte 0xf4, 0xea, 0xe0, 0xd7, 0xd2, 0xcc, 0xc5, 0xbc, 0xb4, 0xab, 0xa2, 0x9c, 0x98, 0x97, 0x95, 0x93
.byte 0x93, 0x99, 0xa0, 0xa9, 0xb1, 0xb8, 0xc1, 0xcc, 0xd6, 0xe3, 0xee, 0xf7, 0xfc, 0x00, 0x01, 0x01
.byte 0x01, 0x00, 0xff, 0xfb, 0xf8, 0xf6, 0xf5, 0xf5, 0xf5, 0xf6, 0xf5, 0xf3, 0xf1, 0xf0, 0xf2, 0xf7
.byte 0xfe, 0x03, 0x06, 0x07, 0x08, 0x08, 0x08, 0x07, 0x06, 0x05, 0x02, 0xff, 0xfa, 0xf8, 0xf7, 0xf8
.byte 0xf7, 0xf5, 0xf2, 0xef, 0xeb, 0xe9, 0xea, 0xed, 0xf2, 0xf5, 0xf4, 0xf2, 0xf1, 0xf4, 0xf9, 0xfe
.byte 0x00, 0xfe, 0xfc, 0xfc, 0xfe, 0x00, 0x00, 0x00, 0x00, 0xff, 0x00, 0x02, 0x09, 0x10, 0x16, 0x1b
.byte 0x1e, 0x1d, 0x1a, 0x17, 0x16, 0x17, 0x1b, 0x1f, 0x22, 0x23, 0x22, 0x21, 0x1f, 0x1c, 0x18, 0x15
.byte 0x11, 0x0c, 0x07, 0x01, 0x00, 0xff, 0xfe, 0xfd, 0xfc, 0xfc, 0xfe, 0x00, 0x01, 0x04, 0x08, 0x0c
.byte 0x0f, 0x11, 0x13, 0x14, 0x15, 0x14, 0x13, 0x10, 0x0d, 0x09, 0x05, 0xfe, 0xf6, 0xee, 0xe7, 0xe3
.byte 0xe1, 0xe0, 0xde, 0xdb, 0xd8, 0xd6, 0xd5, 0xd4, 0xd4, 0xd3, 0xd3, 0xd7, 0xdd, 0xe0, 0xe5, 0xf3
;Synth
.byte 0x00, 0x07, 0x0f, 0x16, 0x1f, 0x26, 0x28, 0x27, 0x23, 0x1e, 0x17, 0x11, 0x0a, 0x03, 0x00, 0x00
.byte 0x00, 0x02, 0x02, 0x04, 0x06, 0x04, 0x02, 0x00, 0xfe, 0xfa, 0xf6, 0xf3, 0xf0, 0xed, 0xea, 0xe8
.byte 0xe8, 0xe9, 0xea, 0xea, 0xeb, 0xec, 0xed, 0xee, 0xee, 0xee, 0xef, 0xf1, 0xf1, 0xf3, 0xf4, 0xf8
.byte 0xf9, 0xf9, 0xfb, 0xfe, 0x03, 0x0e, 0x1d, 0x29, 0x33, 0x37, 0x34, 0x2c, 0x24, 0x1b, 0x0e, 0x06
.byte 0x00, 0xfb, 0xfb, 0x00, 0x03, 0x06, 0x0a, 0x0a, 0x09, 0x08, 0x01, 0xfd, 0xf8, 0xf4, 0xf1, 0xeb
.byte 0xe7, 0xe5, 0xe3, 0xe4, 0xe7, 0xe9, 0xeb, 0xec, 0xea, 0xeb, 0xeb, 0xeb, 0xeb, 0xed, 0xed, 0xef
.byte 0xf2, 0xf3, 0xf6, 0xf7, 0xf8, 0xf9, 0xfc, 0x00, 0x0c, 0x24, 0x3c, 0x49, 0x45, 0x39, 0x2c, 0x23
.byte 0x1d, 0x11, 0x00, 0xf5, 0xf1, 0xf3, 0xff, 0x06, 0x0d, 0x10, 0x10, 0x0f, 0x09, 0x02, 0xfb, 0xf6
.byte 0xf2, 0xef, 0xe9, 0xe1, 0xdc, 0xdb, 0xe1, 0xe9, 0xeb, 0xec, 0xec, 0xe8, 0xe7, 0xe7, 0xe8, 0xe7
.byte 0xe8, 0xe9, 0xec, 0xee, 0xf1, 0xf4, 0xf5, 0xf7, 0xf6, 0xf5, 0xfd, 0x10, 0x31, 0x52, 0x60, 0x51
.byte 0x3c, 0x2e, 0x24, 0x1f, 0x12, 0xf5, 0xe9, 0xe7, 0xf6, 0x03, 0x0f, 0x11, 0x13, 0x12, 0x12, 0x0b
.byte 0x05, 0xfa, 0xf2, 0xf0, 0xed, 0xe3, 0xda, 0xd6, 0xd8, 0xe1, 0xe9, 0xeb, 0xeb, 0xeb, 0xe8, 0xe6
.byte 0xe6, 0xe6, 0xe6, 0xe8, 0xea, 0xea, 0xeb, 0xef, 0xf1, 0xf6, 0xf4, 0xef, 0xee, 0xf8, 0x18, 0x3e
.byte 0x6a, 0x69, 0x53, 0x3e, 0x2e, 0x25, 0x1d, 0x0a, 0xe9, 0xe4, 0xe7, 0xfb, 0x09, 0x16, 0x17, 0x17
.byte 0x15, 0x12, 0x0a, 0xff, 0xf3, 0xed, 0xef, 0xec, 0xe0, 0xd5, 0xd3, 0xd6, 0xdf, 0xee, 0xf1, 0xee
.byte 0xea, 0xe6, 0xe3, 0xe2, 0xe2, 0xe4, 0xe7, 0xe8, 0xe9, 0xeb, 0xf0, 0xf5, 0xf4, 0xf2, 0xea, 0xed
;Sustain
.byte 0xff, 0x03, 0x07, 0x0e, 0x21, 0x27, 0x2e, 0x3c, 0x43, 0x49, 0x56, 0x5d, 0x66, 0x70, 0x73, 0x76
.byte 0x76, 0x74, 0x72, 0x70, 0x68, 0x63, 0x5f, 0x59, 0x56, 0x54, 0x50, 0x4d, 0x4b, 0x48, 0x3f, 0x3d
.byte 0x3b, 0x34, 0x32, 0x2f, 0x2d, 0x2a, 0x28, 0x27, 0x26, 0x25, 0x23, 0x1f, 0x1d, 0x1c, 0x12, 0x0d
.byte 0x0a, 0xff, 0xfa, 0xf5, 0xeb, 0xe7, 0xe4, 0xe2, 0xdf, 0xe0, 0xe1, 0xe2, 0xe1, 0xe2, 0xe2, 0xe3
.byte 0xe5, 0xea, 0xed, 0xf0, 0xf4, 0xfb, 0xff, 0x00, 0x08, 0x0a, 0x0b, 0x10, 0x13, 0x15, 0x16, 0x18
.byte 0x19, 0x19, 0x18, 0x18, 0x18, 0x18, 0x19, 0x18, 0x18, 0x18, 0x19, 0x18, 0x19, 0x19, 0x18, 0x18
.byte 0x17, 0x17, 0x14, 0x12, 0x11, 0x0e, 0x0c, 0x0b, 0x08, 0x06, 0x04, 0xff, 0xfd, 0xfc, 0xfa, 0xf6
.byte 0xf4, 0xf3, 0xf1, 0xf0, 0xef, 0xee, 0xed, 0xec, 0xec, 0xec, 0xed, 0xed, 0xef, 0xef, 0xef, 0xef
.byte 0xef, 0xef, 0xed, 0xeb, 0xe8, 0xe3, 0xe0, 0xdd, 0xdb, 0xd9, 0xd7, 0xd5, 0xd3, 0xd2, 0xd0, 0xcf
.byte 0xce, 0xce, 0xce, 0xcf, 0xd0, 0xd0, 0xd3, 0xd5, 0xd6, 0xda, 0xdd, 0xe0, 0xe5, 0xe9, 0xed, 0xf3
.byte 0xf4, 0xf4, 0xf5, 0xf5, 0xf4, 0xf3, 0xf2, 0xf1, 0xf0, 0xf0, 0xf1, 0xf0, 0xf0, 0xf0, 0xee, 0xed
.byte 0xeb, 0xea, 0xe8, 0xe5, 0xe4, 0xe2, 0xe0, 0xdf, 0xdf, 0xdf, 0xe0, 0xe0, 0xe0, 0xe0, 0xe0, 0xe0
.byte 0xe1, 0xe1, 0xe0, 0xe0, 0xdf, 0xdf, 0xdf, 0xdf, 0xdf, 0xdf, 0xe0, 0xe1, 0xe1, 0xe3, 0xe3, 0xe2
.byte 0xe2, 0xe2, 0xe2, 0xe3, 0xe3, 0xe3, 0xe3, 0xe3, 0xe4, 0xe4, 0xe6, 0xe8, 0xe9, 0xeb, 0xec, 0xed
.byte 0xef, 0xf0, 0xf1, 0xf2, 0xf3, 0xf4, 0xf5, 0xf5, 0xf5, 0xf5, 0xf4, 0xf4, 0xf3, 0xf1, 0xf0, 0xef
.byte 0xeb, 0xea, 0xe9, 0xe8, 0xe6, 0xe3, 0xe1, 0xe0, 0xe0, 0xe1, 0xe2, 0xe4, 0xe4, 0xea, 0xef, 0xf3
;Reed Organ
.byte 0xfd, 0x20, 0x43, 0x60, 0x73, 0x75, 0x6d, 0x62, 0x5a, 0x59, 0x59, 0x55, 0x4c, 0x2d, 0x17, 0x06
.byte 0xfb, 0xf8, 0x0f, 0x24, 0x34, 0x3c, 0x25, 0x09, 0xf2, 0xd7, 0xac, 0xa3, 0x9c, 0x93, 0x86, 0x85
.byte 0x8d, 0x9b, 0xaf, 0xd2, 0xde, 0xe5, 0xe5, 0xd3, 0xcc, 0xca, 0xd4, 0x09, 0x2c, 0x4e, 0x67, 0x76
.byte 0x6f, 0x66, 0x5b, 0x56, 0x59, 0x58, 0x50, 0x46, 0x22, 0x0f, 0x00, 0xfa, 0x00, 0x14, 0x29, 0x37
.byte 0x33, 0x1b, 0x01, 0xe7, 0xcc, 0xa9, 0xa2, 0x9a, 0x92, 0x86, 0x86, 0x91, 0xa2, 0xc8, 0xd5, 0xdd
.byte 0xe2, 0xe1, 0xcf, 0xcc, 0xcf, 0xdc, 0x14, 0x36, 0x53, 0x6a, 0x74, 0x6d, 0x62, 0x5a, 0x57, 0x56
.byte 0x57, 0x50, 0x43, 0x1c, 0x0a, 0xfc, 0xf5, 0x06, 0x1b, 0x2f, 0x38, 0x2b, 0x13, 0xf8, 0xdc, 0xaf
.byte 0xa6, 0x9d, 0x96, 0x8e, 0x83, 0x86, 0x95, 0xa7, 0xca, 0xd6, 0xde, 0xe3, 0xd5, 0xcd, 0xcc, 0xd3
.byte 0x00, 0x20, 0x3f, 0x5c, 0x6b, 0x6e, 0x68, 0x60, 0x58, 0x58, 0x59, 0x56, 0x4b, 0x2d, 0x1b, 0x09
.byte 0xfb, 0xf6, 0x09, 0x1f, 0x2f, 0x39, 0x29, 0x0a, 0xef, 0xd2, 0xab, 0xa2, 0x9c, 0x95, 0x85, 0x81
.byte 0x8a, 0x99, 0xac, 0xcc, 0xd7, 0xde, 0xe2, 0xd5, 0xd0, 0xd1, 0xda, 0x09, 0x29, 0x48, 0x60, 0x72
.byte 0x6d, 0x67, 0x5e, 0x58, 0x5a, 0x5b, 0x56, 0x4c, 0x2b, 0x16, 0x01, 0xf7, 0xfe, 0x0e, 0x25, 0x36
.byte 0x34, 0x21, 0x02, 0xe5, 0xc9, 0xa7, 0xa1, 0x9b, 0x94, 0x82, 0x85, 0x8f, 0xa0, 0xc1, 0xd0, 0xdb
.byte 0xdf, 0xe1, 0xd4, 0xd2, 0xd5, 0xe1, 0x14, 0x34, 0x52, 0x67, 0x71, 0x6b, 0x65, 0x5f, 0x5b, 0x5d
.byte 0x5b, 0x55, 0x48, 0x24, 0x11, 0x00, 0xf7, 0x01, 0x14, 0x2e, 0x3a, 0x2f, 0x17, 0xf6, 0xd8, 0xaf
.byte 0xa4, 0x9d, 0x98, 0x90, 0x81, 0x86, 0x93, 0xa4, 0xc1, 0xd0, 0xd7, 0xdc, 0xdb, 0xd5, 0xd6, 0xdb
.byte 0xfd, 0x20, 0x43, 0x60, 0x73, 0x75, 0x6d, 0x62, 0x5a, 0x59, 0x59, 0x55, 0x4c, 0x2d, 0x17, 0x06
.byte 0xfb, 0xf8, 0x0f, 0x24, 0x34, 0x3c, 0x25, 0x09, 0xf2, 0xd7, 0xac, 0xa3, 0x9c, 0x93, 0x86, 0x85
.byte 0x8d, 0x9b, 0xaf, 0xd2, 0xde, 0xe5, 0xe5, 0xd3, 0xcc, 0xca, 0xd4, 0x09, 0x2c, 0x4e, 0x67, 0x76
.byte 0x6f, 0x66, 0x5b, 0x56, 0x59, 0x58, 0x50, 0x46, 0x22, 0x0f, 0x00, 0xfa, 0x00, 0x14, 0x29, 0x37
.byte 0x33, 0x1b, 0x01, 0xe7, 0xcc, 0xa9, 0xa2, 0x9a, 0x92, 0x86, 0x86, 0x91, 0xa2, 0xc8, 0xd5, 0xdd
.byte 0xe2, 0xe1, 0xcf, 0xcc, 0xcf, 0xdc, 0x14, 0x36, 0x53, 0x6a, 0x74, 0x6d, 0x62, 0x5a, 0x57, 0x56
.byte 0x57, 0x50, 0x43, 0x1c, 0x0a, 0xfc, 0xf5, 0x06, 0x1b, 0x2f, 0x38, 0x2b, 0x13, 0xf8, 0xdc, 0xaf
.byte 0xa6, 0x9d, 0x96, 0x8e, 0x83, 0x86, 0x95, 0xa7, 0xca, 0xd6, 0xde, 0xe3, 0xd5, 0xcd, 0xcc, 0xd3
.byte 0x00, 0x20, 0x3f, 0x5c, 0x6b, 0x6e, 0x68, 0x60, 0x58, 0x58, 0x59, 0x56, 0x4b, 0x2d, 0x1b, 0x09
.byte 0xfb, 0xf6, 0x09, 0x1f, 0x2f, 0x39, 0x29, 0x0a, 0xef, 0xd2, 0xab, 0xa2, 0x9c, 0x95, 0x85, 0x81
.byte 0x8a, 0x99, 0xac, 0xcc, 0xd7, 0xde, 0xe2, 0xd5, 0xd0, 0xd1, 0xda, 0x09, 0x29, 0x48, 0x60, 0x72
.byte 0x6d, 0x67, 0x5e, 0x58, 0x5a, 0x5b, 0x56, 0x4c, 0x2b, 0x16, 0x01, 0xf7, 0xfe, 0x0e, 0x25, 0x36
.byte 0x34, 0x21, 0x02, 0xe5, 0xc9, 0xa7, 0xa1, 0x9b, 0x94, 0x82, 0x85, 0x8f, 0xa0, 0xc1, 0xd0, 0xdb
.byte 0xdf, 0xe1, 0xd4, 0xd2, 0xd5, 0xe1, 0x14, 0x34, 0x52, 0x67, 0x71, 0x6b, 0x65, 0x5f, 0x5b, 0x5d
.byte 0x5b, 0x55, 0x48, 0x24, 0x11, 0x00, 0xf7, 0x01, 0x14, 0x2e, 0x3a, 0x2f, 0x17, 0xf6, 0xd8, 0xaf
.byte 0xa4, 0x9d, 0x98, 0x90, 0x81, 0x86, 0x93, 0xa4, 0xc1, 0xd0, 0xd7, 0xdc, 0xdb, 0xd5, 0xd6, 0xdb
;Dreieck
/*.byte 0x00, 0x02, 0x04, 0x06, 0x08, 0x0A, 0x0C, 0x0E, 0x10, 0x12, 0x14, 0x16, 0x18, 0x1A, 0x1C, 0x1E
.byte 0x20, 0x22, 0x24, 0x26, 0x28, 0x2A, 0x2C, 0x2E, 0x30, 0x32, 0x34, 0x36, 0x38, 0x3A, 0x3C, 0x3E
.byte 0x40, 0x42, 0x44, 0x46, 0x48, 0x4A, 0x4C, 0x4E, 0x50, 0x52, 0x54, 0x56, 0x58, 0x5A, 0x5C, 0x5E
.byte 0x60, 0x62, 0x64, 0x66, 0x68, 0x6A, 0x6C, 0x6E, 0x70, 0x72, 0x74, 0x76, 0x78, 0x7A, 0x7C, 0x7E
.byte 0x7F, 0x7E, 0x7C, 0x7A, 0x78, 0x76, 0x74, 0x72, 0x70, 0x6E, 0x6C, 0x6A, 0x68, 0x66, 0x64, 0x62
.byte 0x60, 0x5E, 0x5C, 0x5A, 0x58, 0x56, 0x54, 0x52, 0x50, 0x4E, 0x4C, 0x4A, 0x48, 0x46, 0x44, 0x42
.byte 0x40, 0x3E, 0x3C, 0x3A, 0x38, 0x36, 0x34, 0x32, 0x30, 0x2E, 0x2C, 0x2A, 0x28, 0x26, 0x24, 0x22
.byte 0x20, 0x1E, 0x1C, 0x1A, 0x18, 0x16, 0x14, 0x12, 0x10, 0x0E, 0x0C, 0x0A, 0x08, 0x06, 0x04, 0x02
.byte 0x00, 0xFE, 0xFC, 0xFA, 0xF8, 0xF6, 0xF4, 0xF2, 0xF0, 0xEE, 0xEC, 0xEA, 0xE8, 0xE6, 0xE4, 0xE2
.byte 0xE0, 0xDE, 0xDC, 0xDA, 0xD8, 0xD6, 0xD4, 0xD2, 0xD0, 0xCE, 0xCC, 0xCA, 0xC8, 0xC6, 0xC4, 0xC2
.byte 0xC0, 0xBE, 0xBC, 0xBA, 0xB8, 0xB6, 0xB4, 0xB2, 0xB0, 0xAE, 0xAC, 0xAA, 0xA8, 0xA6, 0xA4, 0xA2
.byte 0xA0, 0x9E, 0x9C, 0x9A, 0x98, 0x96, 0x94, 0x92, 0x90, 0x8E, 0x8C, 0x8A, 0x88, 0x86, 0x84, 0x82
.byte 0x80, 0x82, 0x84, 0x86, 0x88, 0x8A, 0x8C, 0x8E, 0x90, 0x92, 0x94, 0x96, 0x98, 0x9A, 0x9C, 0x9E
.byte 0xA0, 0xA2, 0xA4, 0xA6, 0xA8, 0xAA, 0xAC, 0xAE, 0xB0, 0xB2, 0xB4, 0xB6, 0xB8, 0xBA, 0xBC, 0xBE
.byte 0xC0, 0xC2, 0xC4, 0xC6, 0xC8, 0xCA, 0xCC, 0xCE, 0xD0, 0xD2, 0xD4, 0xD6, 0xD8, 0xDA, 0xDC, 0xDE
.byte 0xE0, 0xE2, 0xE4, 0xE6, 0xE8, 0xEA, 0xEC, 0xEE, 0xF0, 0xF2, 0xF4, 0xF6, 0xF8, 0xFA, 0xFC, 0xFE
.byte 0x00, 0x02, 0x04, 0x06, 0x08, 0x0A, 0x0C, 0x0E, 0x10, 0x12, 0x14, 0x16, 0x18, 0x1A, 0x1C, 0x1E
.byte 0x20, 0x22, 0x24, 0x26, 0x28, 0x2A, 0x2C, 0x2E, 0x30, 0x32, 0x34, 0x36, 0x38, 0x3A, 0x3C, 0x3E
.byte 0x40, 0x42, 0x44, 0x46, 0x48, 0x4A, 0x4C, 0x4E, 0x50, 0x52, 0x54, 0x56, 0x58, 0x5A, 0x5C, 0x5E
.byte 0x60, 0x62, 0x64, 0x66, 0x68, 0x6A, 0x6C, 0x6E, 0x70, 0x72, 0x74, 0x76, 0x78, 0x7A, 0x7C, 0x7E
.byte 0x7F, 0x7E, 0x7C, 0x7A, 0x78, 0x76, 0x74, 0x72, 0x70, 0x6E, 0x6C, 0x6A, 0x68, 0x66, 0x64, 0x62
.byte 0x60, 0x5E, 0x5C, 0x5A, 0x58, 0x56, 0x54, 0x52, 0x50, 0x4E, 0x4C, 0x4A, 0x48, 0x46, 0x44, 0x42
.byte 0x40, 0x3E, 0x3C, 0x3A, 0x38, 0x36, 0x34, 0x32, 0x30, 0x2E, 0x2C, 0x2A, 0x28, 0x26, 0x24, 0x22
.byte 0x20, 0x1E, 0x1C, 0x1A, 0x18, 0x16, 0x14, 0x12, 0x10, 0x0E, 0x0C, 0x0A, 0x08, 0x06, 0x04, 0x02
.byte 0x00, 0xFE, 0xFC, 0xFA, 0xF8, 0xF6, 0xF4, 0xF2, 0xF0, 0xEE, 0xEC, 0xEA, 0xE8, 0xE6, 0xE4, 0xE2
.byte 0xE0, 0xDE, 0xDC, 0xDA, 0xD8, 0xD6, 0xD4, 0xD2, 0xD0, 0xCE, 0xCC, 0xCA, 0xC8, 0xC6, 0xC4, 0xC2
.byte 0xC0, 0xBE, 0xBC, 0xBA, 0xB8, 0xB6, 0xB4, 0xB2, 0xB0, 0xAE, 0xAC, 0xAA, 0xA8, 0xA6, 0xA4, 0xA2
.byte 0xA0, 0x9E, 0x9C, 0x9A, 0x98, 0x96, 0x94, 0x92, 0x90, 0x8E, 0x8C, 0x8A, 0x88, 0x86, 0x84, 0x82
.byte 0x80, 0x82, 0x84, 0x86, 0x88, 0x8A, 0x8C, 0x8E, 0x90, 0x92, 0x94, 0x96, 0x98, 0x9A, 0x9C, 0x9E
.byte 0xA0, 0xA2, 0xA4, 0xA6, 0xA8, 0xAA, 0xAC, 0xAE, 0xB0, 0xB2, 0xB4, 0xB6, 0xB8, 0xBA, 0xBC, 0xBE
.byte 0xC0, 0xC2, 0xC4, 0xC6, 0xC8, 0xCA, 0xCC, 0xCE, 0xD0, 0xD2, 0xD4, 0xD6, 0xD8, 0xDA, 0xDC, 0xDE
.byte 0xE0, 0xE2, 0xE4, 0xE6, 0xE8, 0xEA, 0xEC, 0xEE, 0xF0, 0xF2, 0xF4, 0xF6, 0xF8, 0xFA, 0xFC, 0xFE*/

;saege
.byte 0x00, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07, 0x08, 0x09, 0x0A, 0x0B, 0x0C, 0x0D, 0x0E, 0x0F
.byte 0x10, 0x11, 0x12, 0x13, 0x14, 0x15, 0x16, 0x17, 0x18, 0x19, 0x1A, 0x1B, 0x1C, 0x1D, 0x1E, 0x1F
.byte 0x20, 0x21, 0x22, 0x23, 0x24, 0x25, 0x26, 0x27, 0x28, 0x29, 0x2A, 0x2B, 0x2C, 0x2D, 0x2E, 0x2F
.byte 0x30, 0x31, 0x32, 0x33, 0x34, 0x35, 0x36, 0x37, 0x38, 0x39, 0x3A, 0x3B, 0x3C, 0x3D, 0x3E, 0x3F
.byte 0x40, 0x41, 0x42, 0x43, 0x44, 0x45, 0x46, 0x47, 0x48, 0x49, 0x4A, 0x4B, 0x4C, 0x4D, 0x4E, 0x4F
.byte 0x50, 0x51, 0x52, 0x53, 0x54, 0x55, 0x56, 0x57, 0x58, 0x59, 0x5A, 0x5B, 0x5C, 0x5D, 0x5E, 0x5F
.byte 0x60, 0x61, 0x62, 0x63, 0x64, 0x65, 0x66, 0x67, 0x68, 0x69, 0x6A, 0x6B, 0x6C, 0x6D, 0x6E, 0x6F
.byte 0x70, 0x71, 0x72, 0x73, 0x74, 0x75, 0x76, 0x77, 0x78, 0x79, 0x7A, 0x7B, 0x7C, 0x7D, 0x7E, 0x7F
.byte 0x80, 0x81, 0x82, 0x83, 0x84, 0x85, 0x86, 0x87, 0x88, 0x89, 0x8A, 0x8B, 0x8C, 0x8D, 0x8E, 0x8F
.byte 0x90, 0x91, 0x92, 0x93, 0x94, 0x95, 0x96, 0x97, 0x98, 0x99, 0x9A, 0x9B, 0x9C, 0x9D, 0x9E, 0x9F
.byte 0xA0, 0xA1, 0xA2, 0xA3, 0xA4, 0xA5, 0xA6, 0xA7, 0xA8, 0xA9, 0xAA, 0xAB, 0xAC, 0xAD, 0xAE, 0xAF
.byte 0xB0, 0xB1, 0xB2, 0xB3, 0xB4, 0xB5, 0xB6, 0xB7, 0xB8, 0xB9, 0xBA, 0xBB, 0xBC, 0xBD, 0xBE, 0xBF
.byte 0xC0, 0xC1, 0xC2, 0xC3, 0xC4, 0xC5, 0xC6, 0xC7, 0xC8, 0xC9, 0xCA, 0xCB, 0xCC, 0xCD, 0xCE, 0xCF
.byte 0xD0, 0xD1, 0xD2, 0xD3, 0xD4, 0xD5, 0xD6, 0xD7, 0xD8, 0xD9, 0xDA, 0xDB, 0xDC, 0xDD, 0xDE, 0xDF
.byte 0xE0, 0xE1, 0xE2, 0xE3, 0xE4, 0xE5, 0xE6, 0xE7, 0xE8, 0xE9, 0xEA, 0xEB, 0xEC, 0xED, 0xEE, 0xEF
.byte 0xF0, 0xF1, 0xF2, 0xF3, 0xF4, 0xF5, 0xF6, 0xF7, 0xF8, 0xF9, 0xFA, 0xFB, 0xFC, 0xFD, 0xFE, 0xFF
.byte 0x00, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07, 0x08, 0x09, 0x0A, 0x0B, 0x0C, 0x0D, 0x0E, 0x0F
.byte 0x10, 0x11, 0x12, 0x13, 0x14, 0x15, 0x16, 0x17, 0x18, 0x19, 0x1A, 0x1B, 0x1C, 0x1D, 0x1E, 0x1F
.byte 0x20, 0x21, 0x22, 0x23, 0x24, 0x25, 0x26, 0x27, 0x28, 0x29, 0x2A, 0x2B, 0x2C, 0x2D, 0x2E, 0x2F
.byte 0x30, 0x31, 0x32, 0x33, 0x34, 0x35, 0x36, 0x37, 0x38, 0x39, 0x3A, 0x3B, 0x3C, 0x3D, 0x3E, 0x3F
.byte 0x40, 0x41, 0x42, 0x43, 0x44, 0x45, 0x46, 0x47, 0x48, 0x49, 0x4A, 0x4B, 0x4C, 0x4D, 0x4E, 0x4F
.byte 0x50, 0x51, 0x52, 0x53, 0x54, 0x55, 0x56, 0x57, 0x58, 0x59, 0x5A, 0x5B, 0x5C, 0x5D, 0x5E, 0x5F
.byte 0x60, 0x61, 0x62, 0x63, 0x64, 0x65, 0x66, 0x67, 0x68, 0x69, 0x6A, 0x6B, 0x6C, 0x6D, 0x6E, 0x6F
.byte 0x70, 0x71, 0x72, 0x73, 0x74, 0x75, 0x76, 0x77, 0x78, 0x79, 0x7A, 0x7B, 0x7C, 0x7D, 0x7E, 0x7F
.byte 0x80, 0x81, 0x82, 0x83, 0x84, 0x85, 0x86, 0x87, 0x88, 0x89, 0x8A, 0x8B, 0x8C, 0x8D, 0x8E, 0x8F
.byte 0x90, 0x91, 0x92, 0x93, 0x94, 0x95, 0x96, 0x97, 0x98, 0x99, 0x9A, 0x9B, 0x9C, 0x9D, 0x9E, 0x9F
.byte 0xA0, 0xA1, 0xA2, 0xA3, 0xA4, 0xA5, 0xA6, 0xA7, 0xA8, 0xA9, 0xAA, 0xAB, 0xAC, 0xAD, 0xAE, 0xAF
.byte 0xB0, 0xB1, 0xB2, 0xB3, 0xB4, 0xB5, 0xB6, 0xB7, 0xB8, 0xB9, 0xBA, 0xBB, 0xBC, 0xBD, 0xBE, 0xBF
.byte 0xC0, 0xC1, 0xC2, 0xC3, 0xC4, 0xC5, 0xC6, 0xC7, 0xC8, 0xC9, 0xCA, 0xCB, 0xCC, 0xCD, 0xCE, 0xCF
.byte 0xD0, 0xD1, 0xD2, 0xD3, 0xD4, 0xD5, 0xD6, 0xD7, 0xD8, 0xD9, 0xDA, 0xDB, 0xDC, 0xDD, 0xDE, 0xDF
.byte 0xE0, 0xE1, 0xE2, 0xE3, 0xE4, 0xE5, 0xE6, 0xE7, 0xE8, 0xE9, 0xEA, 0xEB, 0xEC, 0xED, 0xEE, 0xEF
.byte 0xF0, 0xF1, 0xF2, 0xF3, 0xF4, 0xF5, 0xF6, 0xF7, 0xF8, 0xF9, 0xFA, 0xFB, 0xFC, 0xFD, 0xFE, 0xFF
;trumpet
.byte 0xef, 0xe7, 0xdf, 0xd7, 0xcf, 0xc9, 0xc3, 0xbd, 0xb4, 0xb1, 0xaf, 0xad, 0xac, 0xac, 0xac, 0xad
.byte 0xae, 0xae, 0xaf, 0xb1, 0xb2, 0xb4, 0xb9, 0xbb, 0xbf, 0xc2, 0xc5, 0xc8, 0xcc, 0xd3, 0xd6, 0xd9
.byte 0xdc, 0xdf, 0xe2, 0xe5, 0xe9, 0xeb, 0xed, 0xef, 0xf1, 0xf2, 0xf3, 0xf5, 0xf6, 0xf7, 0xf7, 0xf8
.byte 0xf9, 0xf9, 0xfa, 0xfa, 0xfa, 0xfa, 0xf9, 0xf9, 0xf9, 0xf9, 0xf9, 0xf8, 0xf8, 0xf8, 0xf8, 0xf8
.byte 0xf8, 0xf8, 0xf8, 0xf9, 0xf9, 0xfa, 0xfa, 0xfb, 0xfb, 0xfb, 0xfb, 0xfa, 0xfa, 0xfa, 0xfa, 0xfa
.byte 0xfa, 0xfa, 0xf9, 0xf9, 0xf8, 0xf8, 0xf8, 0xf8, 0xf7, 0xf7, 0xf6, 0xf6, 0xf7, 0xf7, 0xf6, 0xf6
.byte 0xf6, 0xf7, 0xf7, 0xf7, 0xf7, 0xf7, 0xf8, 0xf8, 0xf8, 0xf9, 0xf9, 0xf9, 0xf9, 0xf9, 0xf9, 0xfa
.byte 0xfa, 0xfa, 0xfb, 0xfb, 0xfb, 0xfc, 0xfc, 0xfc, 0xfc, 0xfc, 0xfc, 0xfc, 0xfd, 0xfd, 0xfd, 0xfe
.byte 0xfe, 0xfe, 0xfe, 0xfe, 0xfe, 0xfe, 0xfe, 0xfe, 0xfe, 0xfe, 0xfe, 0xfd, 0xfd, 0xfc, 0xfc, 0xfb
.byte 0xfa, 0xf9, 0xf9, 0xf8, 0xf7, 0xf6, 0xf5, 0xf4, 0xf4, 0xf3, 0xf3, 0xf2, 0xf2, 0xf1, 0xf0, 0xf0
.byte 0xf0, 0xf0, 0xef, 0xef, 0xee, 0xed, 0xed, 0xed, 0xec, 0xec, 0xeb, 0xea, 0xea, 0xea, 0xea, 0xeb
.byte 0xeb, 0xeb, 0xec, 0xec, 0xec, 0xed, 0xee, 0xef, 0xf0, 0xf1, 0xf2, 0xf3, 0xf5, 0xf6, 0xf7, 0xf7
.byte 0xf9, 0xfb, 0xfc, 0xfe, 0xff, 0x00, 0x00, 0x01, 0x03, 0x05, 0x06, 0x07, 0x09, 0x0b, 0x0c, 0x10
.byte 0x13, 0x14, 0x17, 0x19, 0x1b, 0x1e, 0x24, 0x27, 0x2b, 0x2d, 0x31, 0x34, 0x38, 0x3f, 0x42, 0x45
.byte 0x49, 0x4d, 0x51, 0x54, 0x5b, 0x5f, 0x62, 0x65, 0x68, 0x6c, 0x6f, 0x75, 0x78, 0x7a, 0x7b, 0x7c
.byte 0x7c, 0x7c, 0x79, 0x75, 0x71, 0x6c, 0x65, 0x5e, 0x56, 0x44, 0x3c, 0x32, 0x29, 0x1e, 0x13, 0x09
.byte 0xef, 0xe7, 0xdf, 0xd7, 0xcf, 0xc9, 0xc3, 0xbd, 0xb4, 0xb1, 0xaf, 0xad, 0xac, 0xac, 0xac, 0xad
.byte 0xae, 0xae, 0xaf, 0xb1, 0xb2, 0xb4, 0xb9, 0xbb, 0xbf, 0xc2, 0xc5, 0xc8, 0xcc, 0xd3, 0xd6, 0xd9
.byte 0xdc, 0xdf, 0xe2, 0xe5, 0xe9, 0xeb, 0xed, 0xef, 0xf1, 0xf2, 0xf3, 0xf5, 0xf6, 0xf7, 0xf7, 0xf8
.byte 0xf9, 0xf9, 0xfa, 0xfa, 0xfa, 0xfa, 0xf9, 0xf9, 0xf9, 0xf9, 0xf9, 0xf8, 0xf8, 0xf8, 0xf8, 0xf8
.byte 0xf8, 0xf8, 0xf8, 0xf9, 0xf9, 0xfa, 0xfa, 0xfb, 0xfb, 0xfb, 0xfb, 0xfa, 0xfa, 0xfa, 0xfa, 0xfa
.byte 0xfa, 0xfa, 0xf9, 0xf9, 0xf8, 0xf8, 0xf8, 0xf8, 0xf7, 0xf7, 0xf6, 0xf6, 0xf7, 0xf7, 0xf6, 0xf6
.byte 0xf6, 0xf7, 0xf7, 0xf7, 0xf7, 0xf7, 0xf8, 0xf8, 0xf8, 0xf9, 0xf9, 0xf9, 0xf9, 0xf9, 0xf9, 0xfa
.byte 0xfa, 0xfa, 0xfb, 0xfb, 0xfb, 0xfc, 0xfc, 0xfc, 0xfc, 0xfc, 0xfc, 0xfc, 0xfd, 0xfd, 0xfd, 0xfe
.byte 0xfe, 0xfe, 0xfe, 0xfe, 0xfe, 0xfe, 0xfe, 0xfe, 0xfe, 0xfe, 0xfe, 0xfd, 0xfd, 0xfc, 0xfc, 0xfb
.byte 0xfa, 0xf9, 0xf9, 0xf8, 0xf7, 0xf6, 0xf5, 0xf4, 0xf4, 0xf3, 0xf3, 0xf2, 0xf2, 0xf1, 0xf0, 0xf0
.byte 0xf0, 0xf0, 0xef, 0xef, 0xee, 0xed, 0xed, 0xed, 0xec, 0xec, 0xeb, 0xea, 0xea, 0xea, 0xea, 0xeb
.byte 0xeb, 0xeb, 0xec, 0xec, 0xec, 0xed, 0xee, 0xef, 0xf0, 0xf1, 0xf2, 0xf3, 0xf5, 0xf6, 0xf7, 0xf7
.byte 0xf9, 0xfb, 0xfc, 0xfe, 0xff, 0x00, 0x00, 0x01, 0x03, 0x05, 0x06, 0x07, 0x09, 0x0b, 0x0c, 0x10
.byte 0x13, 0x14, 0x17, 0x19, 0x1b, 0x1e, 0x24, 0x27, 0x2b, 0x2d, 0x31, 0x34, 0x38, 0x3f, 0x42, 0x45
.byte 0x49, 0x4d, 0x51, 0x54, 0x5b, 0x5f, 0x62, 0x65, 0x68, 0x6c, 0x6f, 0x75, 0x78, 0x7a, 0x7b, 0x7c
.byte 0x7c, 0x7c, 0x79, 0x75, 0x71, 0x6c, 0x65, 0x5e, 0x56, 0x44, 0x3c, 0x32, 0x29, 0x1e, 0x13, 0x09




;Drums
;Bassdrum
.byte 0x02, 0x07, 0x0c, 0x11, 0x15, 0x17, 0x15, 0x14, 0x11, 0x16, 0x0d, 0xeb, 0xe6, 0xd9, 0xd4, 0xdb
.byte 0xdf, 0xee, 0xee, 0x00, 0x02, 0x17, 0x15, 0x22, 0x1e, 0x24, 0x15, 0xfd, 0xf3, 0xe8, 0xe7, 0xd9
.byte 0xc7, 0xba, 0xb2, 0x98, 0x9a, 0x97, 0x97, 0x90, 0x91, 0x83, 0x94, 0x91, 0xa7, 0xbb, 0xc4, 0xd0
.byte 0xe6, 0xf1, 0xf8, 0xf8, 0x06, 0x09, 0x15, 0x16, 0x1e, 0x15, 0x17, 0x18, 0x18, 0x22, 0x25, 0x35
.byte 0x3e, 0x43, 0x45, 0x4b, 0x54, 0x54, 0x59, 0x5b, 0x57, 0x50, 0x4c, 0x40, 0x38, 0x31, 0x2d, 0x26
.byte 0x1a, 0x17, 0x0a, 0x0b, 0x02, 0x00, 0xfe, 0xf1, 0xe7, 0xe4, 0xde, 0xe5, 0xe4, 0xdf, 0xd7, 0xd0
.byte 0xcb, 0xb1, 0xa7, 0x93, 0x91, 0x87, 0x84, 0x81, 0x81, 0x81, 0x81, 0x80, 0x82, 0x81, 0x90, 0x9f
.byte 0xad, 0xb9, 0xc6, 0xcf, 0xe1, 0xe7, 0xf2, 0xf8, 0x00, 0x0b, 0x0d, 0x0d, 0x07, 0x04, 0x00, 0x05
.byte 0x0a, 0x0f, 0x1d, 0x27, 0x30, 0x37, 0x47, 0x50, 0x55, 0x54, 0x53, 0x4d, 0x49, 0x44, 0x44, 0x40
.byte 0x31, 0x24, 0x13, 0x06, 0xfc, 0xf4, 0xf1, 0xf0, 0xe7, 0xe4, 0xe0, 0xdd, 0xe3, 0xe9, 0xeb, 0xf1
.byte 0xed, 0xec, 0xe5, 0xea, 0xed, 0xee, 0xf8, 0xf9, 0xfd, 0x00, 0x00, 0xff, 0x00, 0x00, 0xfa, 0xfb
.byte 0xfc, 0x01, 0x05, 0x0d, 0x14, 0x1e, 0x27, 0x29, 0x31, 0x36, 0x32, 0x36, 0x36, 0x2d, 0x26, 0x24
.byte 0x22, 0x1a, 0x16, 0x0d, 0x10, 0x0b, 0x03, 0x01, 0x02, 0x02, 0x00, 0x00, 0x06, 0x09, 0x0a, 0x0d
.byte 0x12, 0x10, 0x0e, 0x0f, 0x1b, 0x21, 0x1e, 0x1e, 0x20, 0x1f, 0x1e, 0x20, 0x24, 0x22, 0x24, 0x28
.byte 0x2a, 0x28, 0x26, 0x23, 0x26, 0x24, 0x28, 0x28, 0x2a, 0x2c, 0x2e, 0x30, 0x2f, 0x2d, 0x2d, 0x2f
.byte 0x28, 0x27, 0x24, 0x21, 0x1c, 0x19, 0x17, 0x1d, 0x1f, 0x26, 0x25, 0x27, 0x23, 0x22, 0x21, 0x20
;sustain
.byte 0x00, 0x01, 0x03, 0x06, 0x08, 0x0b, 0x10, 0x14, 0x19, 0x1e, 0x20, 0x21, 0x21, 0x20, 0x20, 0x23
.byte 0x26, 0x28, 0x28, 0x28, 0x29, 0x2d, 0x30, 0x30, 0x30, 0x31, 0x32, 0x35, 0x35, 0x37, 0x39, 0x3b
.byte 0x3b, 0x3a, 0x3a, 0x39, 0x3a, 0x38, 0x38, 0x36, 0x35, 0x33, 0x2f, 0x2c, 0x29, 0x28, 0x27, 0x26
.byte 0x25, 0x26, 0x28, 0x29, 0x27, 0x27, 0x24, 0x22, 0x1e, 0x18, 0x13, 0x10, 0x0c, 0x07, 0x02, 0xff
.byte 0xfc, 0xfa, 0xf9, 0xf6, 0xf2, 0xee, 0xed, 0xec, 0xed, 0xee, 0xee, 0xec, 0xec, 0xed, 0xee, 0xee
.byte 0xf0, 0xf2, 0xf5, 0xf7, 0xf9, 0xf8, 0xf9, 0xf6, 0xf4, 0xf2, 0xf0, 0xf0, 0xf0, 0xf2, 0xf2, 0xf5
.byte 0xf6, 0xf8, 0xf9, 0xfe, 0xfe, 0xfe, 0xfd, 0xfc, 0xfb, 0xfa, 0xfb, 0xfb, 0xfb, 0xfd, 0x00, 0x00
.byte 0x04, 0x08, 0x09, 0x0b, 0x0d, 0x0e, 0x0d, 0x0c, 0x0d, 0x0e, 0x0d, 0x0b, 0x0a, 0x06, 0x04, 0x02
.byte 0xff, 0xfd, 0xfc, 0xf8, 0xf7, 0xf5, 0xf1, 0xf0, 0xee, 0xed, 0xeb, 0xe7, 0xe2, 0xdf, 0xdb, 0xd9
.byte 0xd5, 0xd2, 0xce, 0xca, 0xc7, 0xc6, 0xc5, 0xc5, 0xc6, 0xc8, 0xca, 0xcd, 0xd4, 0xd9, 0xde, 0xe3
.byte 0xea, 0xf2, 0xf7, 0xfc, 0x00, 0x01, 0x02, 0x05, 0x08, 0x09, 0x09, 0x0a, 0x09, 0x08, 0x09, 0x09
.byte 0x09, 0x09, 0x08, 0x09, 0x09, 0x0a, 0x0a, 0x0b, 0x0f, 0x11, 0x14, 0x16, 0x19, 0x1d, 0x1e, 0x1e
.byte 0x1f, 0x20, 0x20, 0x1f, 0x20, 0x1f, 0x1e, 0x1c, 0x1b, 0x1a, 0x19, 0x19, 0x19, 0x17, 0x18, 0x16
.byte 0x14, 0x11, 0x0e, 0x0b, 0x06, 0x03, 0xff, 0xfd, 0xfa, 0xf8, 0xf3, 0xf1, 0xf0, 0xf0, 0xee, 0xec
.byte 0xeb, 0xea, 0xe9, 0xe7, 0xe4, 0xe0, 0xde, 0xdf, 0xe0, 0xe1, 0xe4, 0xe8, 0xeb, 0xee, 0xf0, 0xf1
.byte 0xf1, 0xf2, 0xf2, 0xf3, 0xf4, 0xf4, 0xf6, 0xf5, 0xf4, 0xf4, 0xf2, 0xf2, 0xf1, 0xf2, 0xf1, 0xf1

//Snare
.byte 0x0, 0x0, 0x0, 0x0, 0x0, 0xFF, 0x2, 0x13, 0x24, 0x5, 0xF9, 0xE1, 0xE6, 0xCB, 0xBA, 0xDA
.byte 0x1, 0x7, 0xC, 0x23, 0x51, 0x39, 0x18, 0x11, 0x8, 0xFC, 0xF1, 0xF5, 0xE2, 0xC2, 0xC2, 0xE8
.byte 0xD6, 0xB2, 0xCE, 0xFB, 0x5, 0xD0, 0xE9, 0x2, 0xE, 0x15, 0x1E, 0x24, 0x3F, 0x44, 0x4A, 0x53
.byte 0x4C, 0x2D, 0x1C, 0x3, 0xED, 0xF1, 0xEE, 0xDE, 0xD9, 0xC5, 0xC0, 0xBA, 0xC0, 0xB7, 0xB1, 0xAD
.byte 0xC2, 0xE9, 0xF7, 0x9, 0xD, 0x14, 0x24, 0x2C, 0x3A, 0x42, 0x48, 0x42, 0x42, 0x41, 0x3F, 0x28
.byte 0x10, 0x1, 0xF6, 0xE6, 0xE2, 0xD8, 0xD3, 0xD9, 0xD4, 0xD0, 0xC5, 0xD2, 0xD0, 0xCA, 0xD5, 0xEF
.byte 0x9, 0x14, 0x23, 0x31, 0x44, 0x4B, 0x38, 0x43, 0x39, 0x28, 0x2A, 0x32, 0x32, 0x1F, 0x1C, 0xFB
.byte 0xF1, 0xDD, 0xD1, 0xD1, 0xCE, 0xC3, 0xC0, 0xCA, 0xCF, 0xCB, 0xC8, 0xCB, 0xE7, 0xF5, 0x3, 0xF
.byte 0x25, 0x26, 0x26, 0x24, 0x3F, 0x3E, 0x2E, 0x3C, 0x36, 0x2F, 0x21, 0xFC, 0xF3, 0xE5, 0xD5, 0xCE
.byte 0xCA, 0xD4, 0xD0, 0xCC, 0xD1, 0xC3, 0xE0, 0xD4, 0xD7, 0xE0, 0xEC, 0xF6, 0x0, 0xE, 0x20, 0x20
.byte 0x34, 0x2D, 0x3D, 0x36, 0x3A, 0x20, 0x25, 0x1E, 0x1C, 0x3, 0x1, 0xF6, 0xEF, 0xD6, 0xDD, 0xD6
.byte 0xD0, 0xCE, 0xD5, 0xDA, 0xCC, 0xD5, 0xE2, 0xEA, 0x6, 0x9, 0x15, 0x10, 0x27, 0x1B, 0x35, 0x1D
.byte 0x23, 0x31, 0x25, 0x1B, 0x1C, 0x10, 0x7, 0x8, 0x2, 0x16, 0xFE, 0xF7, 0xEB, 0xF2, 0xD7, 0xD8
.byte 0xD7, 0xE2, 0xCD, 0xDC, 0xD2, 0xDD, 0xF5, 0x4, 0x6, 0x1A, 0x22, 0x12, 0x6, 0x19, 0x20, 0x10
.byte 0x1B, 0x1A, 0x10, 0x13, 0xC, 0x4, 0x7, 0xA, 0x1, 0xF7, 0xFF, 0xF6, 0xF8, 0xE6, 0xF0, 0xF3
.byte 0xEC, 0xEF, 0xF0, 0xEB, 0xED, 0xE4, 0xD6, 0xF5, 0xF1, 0xED, 0xFC, 0x8, 0xE, 0xE, 0x19, 0x13
.byte 0x11, 0xC, 0x10, 0x12, 0x1A, 0x16, 0x1A, 0x8, 0x2, 0xEF, 0xF6, 0xEA, 0xEC, 0xEB, 0xE7, 0xE7
.byte 0xEE, 0xF0, 0xE5, 0xFD, 0xF4, 0xFA, 0xA, 0xF6, 0xF4, 0xF7, 0xFD, 0x6, 0xF6, 0x8, 0x1, 0xFD
.byte 0x1, 0x3, 0x1, 0xC, 0x10, 0x28, 0x12, 0x13, 0x16, 0x10, 0x10, 0x0, 0xFB, 0xF7, 0xF0, 0xE8
.byte 0xF4, 0xEB, 0xF2, 0xF4, 0xEF, 0xF3, 0xF7, 0x2, 0xFE, 0xFE, 0xFF, 0x8, 0xD, 0xB, 0xD, 0xC
.byte 0x4, 0x5, 0xE, 0x4, 0x13, 0x0, 0x9, 0x7, 0x7, 0x3, 0x11, 0x2, 0x3, 0xFA, 0xFB, 0xF3
.byte 0xED, 0xF2, 0xED, 0xF0, 0xEC, 0xF1, 0xFD, 0x5, 0x1, 0x3, 0xB, 0xF, 0xA, 0xA, 0x10, 0x4
.byte 0x2, 0x8, 0x4, 0x3, 0x5, 0x6, 0x8, 0x1, 0x5, 0x6, 0x4, 0xFC, 0x5, 0xFA, 0xFE, 0xF2
.byte 0xFE, 0xFF, 0x0, 0xF6, 0xFF, 0xFE, 0xF7, 0xF6, 0xFA, 0xF8, 0xFB, 0x3, 0xFB, 0x5, 0x0, 0x0
.byte 0x5, 0x5, 0x6, 0x10, 0xE, 0x5, 0x7, 0x7, 0x4, 0xF7, 0xFD, 0xF5, 0xFF, 0xF9, 0xF8, 0xFC
.byte 0x0, 0xFC, 0xFA, 0xFF, 0x0, 0xFB, 0xFC, 0xFC, 0xFD, 0xFD, 0xFB, 0xFB, 0x0, 0xFA, 0xFD, 0x2
.byte 0x3, 0x2, 0x5, 0x1, 0x6, 0xFF, 0x6, 0x5, 0xFF, 0x7, 0xFC, 0xFC, 0xFF, 0xFE, 0xF9, 0xFB
.byte 0xFD, 0xFB, 0xFB, 0xFC, 0xFE, 0x7, 0x6, 0x0, 0x4, 0x3, 0xFD, 0x3, 0xFF, 0xFB, 0x7, 0x4
.byte 0x3, 0x6, 0x6, 0x8, 0x5, 0xFF, 0xFD, 0x0, 0xFA, 0xF8, 0xFE, 0x0, 0xFE, 0xFA, 0xFE, 0x0
.byte 0x5, 0xFB, 0x4, 0x0, 0x0, 0x0, 0x0, 0x1, 0xFE, 0xFC, 0x1, 0x1, 0xFE, 0x4, 0x2, 0x3
.byte 0x4, 0x6, 0x3, 0x2, 0xFD, 0xFB, 0xFE, 0xFB, 0xFC, 0xFE, 0xFD, 0x0, 0xFF, 0x0, 0xFF, 0x1
.byte 0x0, 0x1, 0x0, 0x0, 0x1, 0x1, 0xFF, 0x0, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0

//hihat
.byte 0x00, 0xf0, 0xef, 0x01, 0x46, 0x32, 0x33, 0x1e, 0x49, 0x7f, 0x26, 0x36, 0x15, 0x24, 0xdb, 0x21
.byte 0xd3, 0xf5, 0xe4, 0xe1, 0xfb, 0xd6, 0x06, 0xdb, 0x1e, 0xd5, 0xf2, 0x31, 0xc6, 0xff, 0x08, 0x00
.byte 0x17, 0x0a, 0x0f, 0x02, 0x4d, 0xff, 0x09, 0xf6, 0xfa, 0xdc, 0x14, 0xf9, 0xd1, 0xf1, 0xdf, 0x0e
.byte 0xfd, 0xf0, 0x08, 0xff, 0x1d, 0x0f, 0xfa, 0x00, 0xbe, 0x07, 0xdd, 0x15, 0x1a, 0xe9, 0x08, 0x0e
.byte 0xe3, 0xef, 0xe1, 0x36, 0x09, 0xe5, 0x00, 0x09, 0xfd, 0xcd, 0xf2, 0x29, 0x16, 0xe9, 0x03, 0xff
.byte 0x16, 0xf7, 0xec, 0xf8, 0x03, 0xf2, 0xc8, 0xf7, 0xf4, 0xff, 0xf7, 0xf7, 0xff, 0xf7, 0x14, 0xee
.byte 0x11, 0x1f, 0x0b, 0x02, 0xf0, 0x28, 0x12, 0xf3, 0x06, 0xfd, 0xf6, 0xfc, 0xee, 0xf6, 0xe7, 0xec
.byte 0x18, 0x19, 0xf0, 0xfa, 0x24, 0xdd, 0x08, 0x28, 0xf7, 0x05, 0x0c, 0x3d, 0x06, 0x0d, 0xf0, 0x08
.byte 0x1a, 0xf5, 0x07, 0xe9, 0x16, 0xff, 0xe5, 0x0f, 0x07, 0xdf, 0xe4, 0xdd, 0x05, 0x2d, 0x07, 0xda
.byte 0x02, 0x0e, 0xff, 0x26, 0xe7, 0xee, 0xef, 0x05, 0xf3, 0xef, 0x00, 0x0e, 0x1a, 0x2b, 0xf5, 0x1d
.byte 0x11, 0x18, 0xf6, 0xe8, 0x1c, 0x41, 0xde, 0xf6, 0xfc, 0x10, 0x0c, 0xf4, 0x04, 0xf0, 0xe9, 0x14
.byte 0x0c, 0xfe, 0xe9, 0x07, 0x16, 0x00, 0xdc, 0xf1, 0x17, 0x0f, 0xf6, 0xfa, 0xd9, 0xff, 0xf3, 0xfe
.byte 0x03, 0x00, 0x0f, 0x0c, 0x00, 0x03, 0xfc, 0x0e, 0xd3, 0xe6, 0x11, 0x25, 0x06, 0x00, 0x08, 0xe2
.byte 0xe9, 0x05, 0xfc, 0x16, 0xf9, 0x06, 0x14, 0x14, 0xf1, 0x2b, 0x23, 0x0d, 0x05, 0x13, 0x02, 0xda
.byte 0x00, 0x02, 0x14, 0xf9, 0xd3, 0xf3, 0x11, 0x15, 0xf7, 0xf1, 0x09, 0x39, 0x00, 0x03, 0xff, 0x03
.byte 0x08, 0xfb, 0xf0, 0xfe, 0x08, 0x0a, 0x05, 0xef, 0x07, 0xec, 0xf3, 0x0d, 0x00, 0xdd, 0x0a, 0x1a
.byte 0x10, 0xfb, 0x0c, 0xfa, 0x08, 0xfe, 0x00, 0x00, 0x04, 0x00, 0xf6, 0xf7, 0x1a, 0x15, 0x1a, 0x05
.byte 0xeb, 0x34, 0xf6, 0x10, 0xed, 0x00, 0x07, 0xf5, 0xee, 0x0d, 0x11, 0x0b, 0xf1, 0xf9, 0xf5, 0x12
.byte 0x00, 0x02, 0x0a, 0x0d, 0x01, 0xf2, 0xfb, 0xed, 0x08, 0xf9, 0xe9, 0xf0, 0xf1, 0xfa, 0x05, 0xfa
.byte 0x00, 0xf8, 0x02, 0x00, 0xf2, 0x0e, 0x0a, 0x0a, 0xf6, 0xf6, 0x13, 0x10, 0x06, 0x06, 0xf2, 0xeb
.byte 0xf1, 0x01, 0xf5, 0xf0, 0xfb, 0xe5, 0x05, 0x03, 0xe9, 0x0c, 0x09, 0xfe, 0xf9, 0xf3, 0xfe, 0x13
.byte 0xf2, 0xe9, 0xeb, 0x29, 0x04, 0xff, 0x08, 0x0c, 0x1b, 0xfd, 0xf3, 0xfc, 0x12, 0xff, 0x01, 0xf6
.byte 0x0a, 0x05, 0x08, 0xeb, 0xeb, 0x0a, 0x1a, 0x03, 0xe9, 0xff, 0xf4, 0x0a, 0xfc, 0xf3, 0x00, 0x00
.byte 0x08, 0xf3, 0xff, 0xf6, 0x11, 0x12, 0xf7, 0xf8, 0xfe, 0xfa, 0x0c, 0x03, 0xf9, 0xff, 0x0e, 0x00
.byte 0xfa, 0xfc, 0x03, 0x00, 0xfa, 0xf0, 0x09, 0x00, 0x0b, 0x0c, 0x00, 0xf7, 0x09, 0x01, 0x00, 0xf9
.byte 0x00, 0x14, 0x00, 0x00, 0x12, 0x07, 0x00, 0xf9, 0x0f, 0x0c, 0x0c, 0xf5, 0x00, 0xff, 0xff, 0xfc
.byte 0xfb, 0x00, 0x09, 0xfb, 0xff, 0xed, 0xea, 0x0e, 0xf8, 0x05, 0xe8, 0xf9, 0xfd, 0x11, 0x07, 0xfd
.byte 0x09, 0x01, 0xf7, 0x04, 0x01, 0x0c, 0x0f, 0x04, 0x05, 0x05, 0x05, 0xf6, 0xf7, 0xf7, 0xf7, 0xfd
.byte 0x12, 0xf4, 0xfa, 0x00, 0x01, 0x10, 0x0d, 0xe8, 0x02, 0xf1, 0x01, 0x00, 0x03, 0x01, 0x04, 0x02
.byte 0xff, 0xf9, 0x0f, 0x04, 0xfd, 0xfa, 0xfa, 0x0a, 0xf8, 0xf9, 0xf9, 0x0f, 0xfa, 0xf3, 0x02, 0x05
.byte 0xfb, 0x03, 0x0c, 0xff, 0x00, 0x07, 0x05, 0xf9, 0xf8, 0x07, 0x03, 0x02, 0xfe, 0xfc, 0xfe, 0xfe
.byte 0xf8, 0xfe, 0xfb, 0x04, 0xf9, 0x00, 0x0a, 0x09, 0x05, 0x0a, 0x03, 0x00, 0x00, 0xfd, 0x04, 0xfe

.global SoundInfo
SoundInfo: 	//Laenge eines Datensatzes wird in SoundInfoLen gespeichert
;Teiler des Attacksamples, Sustainteiler, Attackgeschw., Abklinggeschwindigkeit (Decay)
.byte 6, 1, 0, 6	;Xylophone (MusicBox by ElmChaN)
.byte 5, 1, 0, 4    ;Harpsichord
.byte 5, 1, 0, 0	;Synth
.byte 6, 6, 50, 0	;Reed Organ
.byte 1, 1, 0, 0
.byte 1, 1, 0, 0
.byte 1, 1, 0, 50	;Bassdrum
.byte 1, 1, 0, 0	;Snare by minifloat
.byte 1, 1, 0, 0	;Hihat

.end
