/* Synthesizer Beispiel-Programm fr SD-Karte, LCD und Taster
 * SD-Karte an SPI anschlieen, CS an SS
 * LCD siehe lcd.h
 * Taster gegen GND an PORTC PIN 0-3
 * KEY_BACK  0
 * KEY_RIGHT 1
 * KEY_LEFT  2
 * KEY_ENTER 3
 *
 */


#include <avr/io.h>
#include <avr/interrupt.h>
#include <avr/pgmspace.h>
#include <util/delay.h>
#include <avr/wdt.h>
#include <string.h>
#include <stdint.h>
#include "Synthesizer.h"
#include "Sequencer.h"

#include "lcd.h"

#include "sd/mmc_config.h"	// Hier werden alle noetigen Konfigurationen vorgenommen, umbedingt anschauen !
#include "sd/file.h"
#include "sd/fat.h"
#include "sd/mmc.h"		// Hardware abhaengig
#include "uart.h"		// Hardware abhaengig, es kann auch eine eigene eingebunden werden !
#include "utils.h"

#define MIDI_BUF_LEN 256		//256 Byte Lesepuffer fr SD-Karte
								//Mglich sind alle 2er Potenzen
								//Allerdings kann es bei tonreichen Stcken zu
								//Fehlern kommen. 
uint8_t midi[MIDI_BUF_LEN];	

uint8_t ReadBuffer(uint8_t* pos)
{
	uint8_t index = (uint16_t)pos;
	return midi[index & (MIDI_BUF_LEN-1)];
}

uint8_t current_file = 0;
uint8_t selected_file = 0;
char buffer[12];

uint8_t strcontains(char *ptr, char c)
{
	while(*ptr)
		if(c == *ptr++)
			return 1;
	return 0;
}
void getFile(char *ptr)
{
	if(current_file++ == selected_file)
		strcpy(buffer, ptr);
}

int __attribute__((OS_main))
main(void)
{
	wdt_disable();
	//Synthesizer init
	synth_init();
	lcd_init(LCD_DISP_ON);
	sei();
	//Timer fr SD-Karte und Tastenentprellung initialisieren
	timer0_init();
	//Uart init
	uinit();

	//SD-Karte initialisieren
	lcd_puts("Boot");
	while(mmc_init() == FALSE)
	{
		lcd_gotoxy(0,1);
		lcd_puts("mmc_init failed!");
	}
	lcd_puts("...");
	while(fat_loadFatData() == FALSE)
	{
		lcd_gotoxy(0,1);
		lcd_puts("FatData failed!");
	}
	lcd_clrscr();
	selected_file = 0;
	while(1)
	{
		uint8_t key;
	FileSelect:;
		do
		{
			do
				key = get_key_press(ALL_KEYS);
			while(!key);
			lcd_clrscr();
			if(key & (1<<KEY_LEFT))
				selected_file--;
			if(key & (1<<KEY_RIGHT))
				selected_file++;
			current_file = 0;
			ffls_ex(getFile);
			lcd_puts(buffer);
			uputs((uint8_t*)buffer);
		}
		while(!(key & (1<<KEY_ENTER)));

		if(MMC_FILE_OPENED != ffopen((uint8_t*)buffer, 'r'))
		{
			char* ptr = buffer;
			char* dest = buffer;
			while(*ptr)
			{
				if(*ptr != ' ')
					*dest++ = *ptr;
				ptr++;
			}
			if(MMC_FILE_OPENED != ffopen((uint8_t*)buffer, 'r'))
			{
				lcd_puts("\nError opening!");
				goto FileSelect;
			}
		}
		lcd_puts("\nopened.");

		//Lesepuffer fllen
		uint8_t i = 0;
		do
			midi[i] = ffread();
		while(++i != (MIDI_BUF_LEN & 0xFF));
		//Leseindex auf 0 setzen
		uint8_t write = 0;

		//Datei vom Sequenzer laden
		if(seq_load(ReadBuffer, 0) == 0)
		{
			//Synthesizer und Sequenzer starten
			synth_start();
			seq_start();

			do
			{
				//Synthesizerupdate; Diese Funktion muss mindestens im 1ms Intervall aufgerufen werden
				synth_update();
				//Leseindex mit Schreibindex vergleichen
				uint8_t read = (uint8_t)(uint16_t)Seq.file;
				while(read != write)
				{
					//Buffer wieder auffllen
					midi[write++ & (MIDI_BUF_LEN-1)] = ffread();
				}
				if(get_key_press(ALL_KEYS) & 1<<KEY_BACK)
					break; 
			}
			while(seq_running());
			seq_stop();
			synth_stop();
		}
		else
			uputs("Zu wenig Kanle");
		ffclose();
	}
	return 0;
}
